/* This file is automatically generated by i386-gen.  Do not edit!  */
/* Copyright (C) 2007-2024 Free Software Foundation, Inc.

   This file is part of the GNU opcodes library.

   This library is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   It is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

extern const char i386_mnemonics[];

#define MN_ud0 0x1
#define MN_prefetcht0 0x5
#define MN_prefetchit0 0x10
#define MN_xsha1 0x1c
#define MN_fld1 0x22
#define MN_ud1 0x27
#define MN_sha1msg1 0x2b
#define MN_vsha512msg1 0x34
#define MN_vsm3msg1 0x40
#define MN_sha256msg1 0x49
#define MN_fprem1 0x54
#define MN_f2xm1 0x5b
#define MN_fyl2xp1 0x61
#define MN_tileloaddt1 0x69
#define MN_prefetcht1 0x75
#define MN_prefetchit1 0x80
#define MN_pfrcpit1 0x8c
#define MN_pfrsqit1 0x95
#define MN_int1 0x9e
#define MN_prefetchwt1 0xa3
#define MN_vmovdqa32 0xaf
#define MN_data32 0xb9
#define MN_crc32 0xc0
#define MN_endbr32 0xc6
#define MN_addr32 0xce
#define MN_vmovdqu32 0xd5
#define MN_ud2 0xdf
#define MN_fldlg2 0xe3
#define MN_sha1msg2 0xea
#define MN_vsha512msg2 0xf3
#define MN_vsm3msg2 0xff
#define MN_sha256msg2 0x108
#define MN_push2 0x113
#define MN_sm2 0x119
#define MN_fldln2 0x11d
#define MN_pop2 0x124
#define MN_vsha512rnds2 0x129
#define MN_vsm3rnds2 0x136
#define MN_sha256rnds2 0x140
#define MN_prefetcht2 0x14c
#define MN_pfrcpit2 0x157
#define MN_vbroadcastf32x2 0x160
#define MN_vbroadcasti32x2 0x170
#define MN_vshuff64x2 0x180
#define MN_vextractf64x2 0x18b
#define MN_vinsertf64x2 0x199
#define MN_vbroadcastf64x2 0x1a6
#define MN_vshufi64x2 0x1b6
#define MN_vextracti64x2 0x1c1
#define MN_vinserti64x2 0x1cf
#define MN_vbroadcasti64x2 0x1dc
#define MN_sm3 0x1ec
#define MN_int3 0x1f0
#define MN_vmovdqa64 0x1f5
#define MN_xsavec64 0x1ff
#define MN_xsave64 (MN_fxsave64 + 1)
#define MN_fxsave64 0x208
#define MN_endbr64 0x211
#define MN_xrstor64 (MN_fxrstor64 + 1)
#define MN_fxrstor64 0x219
#define MN_xsaves64 0x223
#define MN_xrstors64 0x22c
#define MN_xsaveopt64 0x236
#define MN_vmovdqu64 0x241
#define MN_rex64 0x24b
#define MN_sm4 0x251
#define MN_sha1rnds4 0x255
#define MN_vsm4rnds4 0x25f
#define MN_vshuff32x4 0x269
#define MN_vextractf32x4 0x274
#define MN_vinsertf32x4 0x282
#define MN_vbroadcastf32x4 0x28f
#define MN_vshufi32x4 0x29f
#define MN_vextracti32x4 0x2aa
#define MN_vinserti32x4 0x2b8
#define MN_vbroadcasti32x4 0x2c5
#define MN_vextractf64x4 0x2d5
#define MN_vinsertf64x4 0x2e3
#define MN_vbroadcastf64x4 0x2f0
#define MN_vextracti64x4 0x300
#define MN_vinserti64x4 0x30e
#define MN_vbroadcasti64x4 0x31b
#define MN_vsm4key4 0x32b
#define MN_data16 0x334
#define MN_vcvtne2ps2bf16 0x33b
#define MN_vcvtneps2bf16 0x34a
#define MN_vfmsub231nepbf16 0x358
#define MN_vfnmsub231nepbf16 0x369
#define MN_vfmadd231nepbf16 0x37b
#define MN_vfnmadd231nepbf16 0x38c
#define MN_vfmsub132nepbf16 0x39e
#define MN_vfnmsub132nepbf16 0x3af
#define MN_vfmadd132nepbf16 0x3c1
#define MN_vfnmadd132nepbf16 0x3d2
#define MN_vfmsub213nepbf16 0x3e4
#define MN_vfnmsub213nepbf16 0x3f5
#define MN_vfmadd213nepbf16 0x407
#define MN_vfnmadd213nepbf16 0x418
#define MN_vsubnepbf16 0x42a
#define MN_vaddnepbf16 0x436
#define MN_vreducenepbf16 0x442
#define MN_vrndscalenepbf16 0x451
#define MN_vscalefnepbf16 0x462
#define MN_vmulnepbf16 0x471
#define MN_vsqrtnepbf16 0x47d
#define MN_vdivnepbf16 0x48a
#define MN_vminpbf16 0x496
#define MN_vrcppbf16 0x4a0
#define MN_vcmppbf16 0x4aa
#define MN_vgetexppbf16 0x4b4
#define MN_vfpclasspbf16 0x4c1
#define MN_vgetmantpbf16 0x4cf
#define MN_vrsqrtpbf16 0x4dd
#define MN_vminmaxpbf16 0x4e9
#define MN_vmaxpbf16 0x4f6
#define MN_vcomsbf16 0x500
#define MN_addr16 0x50a
#define MN_vmovdqu16 0x511
#define MN_xsha256 0x51b
#define MN_encodekey256 0x523
#define MN_vperm2f128 0x530
#define MN_vextractf128 0x53b
#define MN_vinsertf128 0x548
#define MN_vbroadcastf128 0x554
#define MN_vperm2i128 0x563
#define MN_vextracti128 0x56e
#define MN_vinserti128 0x57b
#define MN_vbroadcasti128 0x587
#define MN_encodekey128 0x596
#define MN_vcvtne2ph2bf8 0x5a3
#define MN_vcvtneph2bf8 0x5b1
#define MN_vcvtbiasph2bf8 0x5be
#define MN_vcvtne2ph2hf8 0x5cd
#define MN_vcvtneph2hf8 0x5db
#define MN_vcvtbiasph2hf8 0x5e8
#define MN_vmovdqu8 0x5f7
#define MN_vextractf32x8 0x600
#define MN_vinsertf32x8 0x60e
#define MN_vbroadcastf32x8 0x61b
#define MN_vextracti32x8 0x62b
#define MN_vinserti32x8 0x639
#define MN_vbroadcasti32x8 0x646
#define MN_ud2a 0x656
#define MN_aaa 0x65b
#define MN_daa 0x65f
#define MN_ssca 0x663
#define MN_lea 0x668
#define MN_invlpga 0x66c
#define MN_pusha 0x674
#define MN_ja 0x67a
#define MN_jna 0x67d
#define MN_ccmpna 0x681
#define MN_setna 0x688
#define MN_ctestna 0x68e
#define MN_setzuna 0x696
#define MN_cmovna (MN_fcmovna + 1)
#define MN_fcmovna (MN_cfcmovna + 1)
#define MN_cfcmovna 0x69e
#define MN_ccmpa 0x6a7
#define MN_popa 0x6ad
#define MN_movntdqa (MN_vmovntdqa + 1)
#define MN_vmovntdqa 0x6b2
#define MN_movdqa (MN_vmovdqa + 1)
#define MN_vmovdqa 0x6bc
#define MN_seta 0x6c4
#define MN_prefetchnta 0x6c9
#define MN_ctesta 0x6d5
#define MN_setzua 0x6dc
#define MN_cmova (MN_fcmova + 1)
#define MN_fcmova (MN_cfcmova + 1)
#define MN_cfcmova 0x6e3
#define MN_rex_b 0x6eb
#define MN_ud2b 0x6f1
#define MN_vpermi2b 0x6f6
#define MN_vpmovm2b 0x6ff
#define MN_vpermt2b 0x708
#define MN_movdir64b 0x711
#define MN_cmpxchg16b 0x71b
#define MN_cmpxchg8b 0x726
#define MN_vpshab 0x730
#define MN_sbb 0x737
#define MN_psubb (MN_vpsubb + 1)
#define MN_vpsubb 0x73b
#define MN_xcrypt_ecb 0x742
#define MN_xcryptecb 0x74d
#define MN_llwpcb 0x757
#define MN_slwpcb 0x75e
#define MN_kaddb 0x765
#define MN_paddb (MN_vpaddb + 1)
#define MN_vpaddb 0x76b
#define MN_kandb 0x772
#define MN_vpexpandb 0x778
#define MN_vpmovusdb 0x782
#define MN_vpmovsdb 0x78c
#define MN_vpmovdb 0x795
#define MN_vpcomgeb 0x79d
#define MN_vpcomleb 0x7a6
#define MN_vpcmpnleb 0x7af
#define MN_vpcmpleb 0x7b9
#define MN_vpcomfalseb 0x7c2
#define MN_vpcomtrueb 0x7ce
#define MN_xcrypt_cfb 0x7d9
#define MN_xcryptcfb 0x7e4
#define MN_xcrypt_ofb 0x7ee
#define MN_xcryptofb 0x7f9
#define MN_pshufb (MN_vpshufb + 1)
#define MN_vpshufb 0x803
#define MN_invlpgb 0x80b
#define MN_pavgb (MN_vpavgb + 1)
#define MN_vpavgb 0x813
#define MN_jb 0x81a
#define MN_pbndkb 0x81d
#define MN_pmovmskb (MN_vpmovmskb + 1)
#define MN_vpmovmskb 0x824
#define MN_vpshlb 0x82e
#define MN_kshiftlb 0x835
#define MN_gf2p8mulb (MN_vgf2p8mulb + 1)
#define MN_vgf2p8mulb 0x83e
#define MN_vpblendmb 0x849
#define MN_vptestnmb 0x853
#define MN_vpcomb 0x85d
#define MN_vpshufbitqmb 0x864
#define MN_vpermb 0x871
#define MN_vptestmb 0x878
#define MN_kandnb 0x881
#define MN_psignb (MN_vpsignb + 1)
#define MN_vpsignb 0x888
#define MN_jnb 0x890
#define MN_ccmpnb 0x894
#define MN_setnb 0x89b
#define MN_ctestnb 0x8a1
#define MN_setzunb 0x8a9
#define MN_cmovnb (MN_fcmovnb + 1)
#define MN_fcmovnb (MN_cfcmovnb + 1)
#define MN_cfcmovnb 0x8b1
#define MN_ccmpb 0x8ba
#define MN_vpcmpb 0x8c0
#define MN_vpcomeqb 0x8c7
#define MN_gf2p8affineqb (MN_vgf2p8affineqb + 1)
#define MN_vgf2p8affineqb 0x8d0
#define MN_vpcomneqb 0x8df
#define MN_vpcmpneqb 0x8e9
#define MN_pcmpeqb (MN_vpcmpeqb + 1)
#define MN_vpcmpeqb 0x8f3
#define MN_vpmovusqb 0x8fc
#define MN_vpmovsqb 0x906
#define MN_vpmultishiftqb 0x90f
#define MN_gf2p8affineinvqb (MN_vgf2p8affineinvqb + 1)
#define MN_vgf2p8affineinvqb 0x91e
#define MN_vpmovqb 0x930
#define MN_rex_rb 0x938
#define MN_korb 0x93f
#define MN_kxnorb 0x944
#define MN_kxorb 0x94b
#define MN_pinsrb (MN_vpinsrb + 1)
#define MN_vpinsrb 0x951
#define MN_kshiftrb 0x959
#define MN_pextrb (MN_vpextrb + 1)
#define MN_vpextrb 0x962
#define MN_rex_wrb 0x96a
#define MN_pabsb (MN_vpabsb + 1)
#define MN_vpabsb 0x972
#define MN_psubsb (MN_vpsubsb + 1)
#define MN_vpsubsb 0x979
#define MN_paddsb (MN_vpaddsb + 1)
#define MN_vpaddsb 0x981
#define MN_pminsb (MN_vpminsb + 1)
#define MN_vpminsb 0x989
#define MN_vpcompressb 0x991
#define MN_psubusb (MN_vpsubusb + 1)
#define MN_vpsubusb 0x99d
#define MN_paddusb (MN_vpaddusb + 1)
#define MN_vpaddusb 0x9a6
#define MN_pavgusb 0x9af
#define MN_movsb 0x9b7
#define MN_pmaxsb (MN_vpmaxsb + 1)
#define MN_vpmaxsb 0x9bd
#define MN_setb 0x9c5
#define MN_vpcomgtb 0x9ca
#define MN_pcmpgtb (MN_vpcmpgtb + 1)
#define MN_vpcmpgtb 0x9d3
#define MN_vpcomltb 0x9dc
#define MN_vpcmpnltb 0x9e5
#define MN_vpcmpltb 0x9ef
#define MN_vpopcntb 0x9f8
#define MN_knotb 0xa01
#define MN_vprotb 0xa07
#define MN_vpbroadcastb 0xa0e
#define MN_ctestb 0xa1b
#define MN_ktestb 0xa22
#define MN_kortestb 0xa29
#define MN_vpcomgeub 0xa32
#define MN_vpcomleub 0xa3c
#define MN_vpcmpnleub 0xa46
#define MN_vpcmpleub 0xa51
#define MN_vpcomfalseub 0xa5b
#define MN_vpcomtrueub 0xa68
#define MN_vpcomub 0xa74
#define MN_pminub (MN_vpminub + 1)
#define MN_vpminub 0xa7c
#define MN_vpcmpub 0xa84
#define MN_vpcomequb 0xa8c
#define MN_vpcomnequb 0xa96
#define MN_vpcmpnequb 0xaa1
#define MN_vpcmpequb 0xaac
#define MN_sub (MN_fsub + 1)
#define MN_fsub (MN_pfsub + 1)
#define MN_pfsub 0xab6
#define MN_fisub 0xabc
#define MN_vpcomgtub 0xac2
#define MN_vpcomltub 0xacc
#define MN_vpcmpnltub 0xad6
#define MN_vpcmpltub 0xae1
#define MN_pmaxub (MN_vpmaxub + 1)
#define MN_vpmaxub 0xaeb
#define MN_setzub 0xaf3
#define MN_pblendvb (MN_vpblendvb + 1)
#define MN_vpblendvb 0xafa
#define MN_cmovb (MN_fcmovb + 1)
#define MN_fcmovb (MN_cfcmovb + 1)
#define MN_cfcmovb 0xb04
#define MN_kmovb 0xb0c
#define MN_rex_wb 0xb12
#define MN_clwb 0xb19
#define MN_packsswb (MN_vpacksswb + 1)
#define MN_vpacksswb 0xb1e
#define MN_packuswb (MN_vpackuswb + 1)
#define MN_vpackuswb 0xb28
#define MN_vpmovuswb 0xb32
#define MN_vpmovswb 0xb3c
#define MN_vpmovwb 0xb45
#define MN_rex_xb 0xb4d
#define MN_rex_rxb 0xb54
#define MN_rex_wrxb 0xb5c
#define MN_rex_wxb 0xb65
#define MN_movzb 0xb6d
#define MN_clac 0xb73
#define MN_stac 0xb78
#define MN_xcrypt_cbc 0xb7d
#define MN_xcryptcbc 0xb88
#define MN_pfacc 0xb92
#define MN_pfnacc 0xb98
#define MN_pfpnacc 0xb9f
#define MN_adc 0xba7
#define MN_dec (MN_aesdec + 3)
#define MN_aesdec (MN_vaesdec + 1)
#define MN_vaesdec 0xbab
#define MN_getsec 0xbb3
#define MN_xsavec 0xbba
#define MN_blcic 0xbc1
#define MN_blsic 0xbc7
#define MN_jc 0xbcd
#define MN_t1mskc 0xbd0
#define MN_clc 0xbd7
#define MN_cmc 0xbdb
#define MN_aesimc (MN_vaesimc + 1)
#define MN_vaesimc 0xbdf
#define MN_rdpmc 0xbe7
#define MN_aesenc (MN_vaesenc + 1)
#define MN_vaesenc 0xbed
#define MN_inc 0xbf5
#define MN_jnc 0xbf9
#define MN_ccmpnc 0xbfd
#define MN_setnc 0xc04
#define MN_ctestnc 0xc0a
#define MN_vmfunc 0xc12
#define MN_setzunc 0xc19
#define MN_cmovnc (MN_cfcmovnc + 2)
#define MN_cfcmovnc 0xc21
#define MN_tlbsync 0xc2a
#define MN_ccmpc 0xc32
#define MN_rdtsc 0xc38
#define MN_btc 0xc3e
#define MN_setc 0xc42
#define MN_stc (MN_ctestc + 3)
#define MN_ctestc 0xc47
#define MN_setzuc 0xc4e
#define MN_cmovc (MN_cfcmovc + 2)
#define MN_cfcmovc 0xc55
#define MN_vpermi2d 0xc5d
#define MN_vpmovm2d 0xc66
#define MN_vpermt2d 0xc6f
#define MN_vpbroadcastmw2d 0xc78
#define MN_aad 0xc88
#define MN_vmread 0xc8c
#define MN_vpshad 0xc93
#define MN_vmload 0xc9a
#define MN_psrad (MN_vpsrad + 1)
#define MN_vpsrad 0xca1
#define MN_vphaddbd 0xca8
#define MN_vphaddubd 0xcb1
#define MN_phsubd (MN_vphsubd + 1)
#define MN_vphsubd 0xcbb
#define MN_psubd (MN_vpsubd + 1)
#define MN_vpsubd 0xcc3
#define MN_pmovsxbd (MN_vpmovsxbd + 1)
#define MN_vpmovsxbd 0xcca
#define MN_pmovzxbd (MN_vpmovzxbd + 1)
#define MN_vpmovzxbd 0xcd4
#define MN_add (MN_aadd + 1)
#define MN_aadd 0xcde
#define MN_fadd (MN_pfadd + 1)
#define MN_pfadd 0xce3
#define MN_fiadd 0xce9
#define MN_tileloadd 0xcef
#define MN_xadd (MN_cmpnaxadd + 5)
#define MN_cmpnaxadd 0xcf9
#define MN_cmpaxadd 0xd03
#define MN_cmpnbxadd 0xd0c
#define MN_cmpbxadd 0xd16
#define MN_cmpncxadd 0xd1f
#define MN_cmpcxadd 0xd29
#define MN_cmpnaexadd 0xd32
#define MN_cmpaexadd 0xd3d
#define MN_cmpnbexadd 0xd47
#define MN_cmpbexadd 0xd52
#define MN_cmpngexadd 0xd5c
#define MN_cmpgexadd 0xd67
#define MN_cmpnlexadd 0xd71
#define MN_cmplexadd 0xd7c
#define MN_cmpnexadd 0xd86
#define MN_cmpexadd 0xd90
#define MN_cmppexadd 0xd99
#define MN_cmpngxadd 0xda3
#define MN_cmpgxadd 0xdad
#define MN_cmpnlxadd 0xdb6
#define MN_cmplxadd 0xdc0
#define MN_cmpnoxadd 0xdc9
#define MN_cmpoxadd 0xdd3
#define MN_cmppoxadd 0xddc
#define MN_cmpnpxadd 0xde6
#define MN_cmppxadd 0xdf0
#define MN_cmpnsxadd 0xdf9
#define MN_cmpsxadd 0xe03
#define MN_cmpnzxadd 0xe0c
#define MN_cmpzxadd 0xe16
#define MN_phaddd (MN_vphaddd + 1)
#define MN_vphaddd 0xe1f
#define MN_kaddd 0xe27
#define MN_paddd (MN_vpaddd + 1)
#define MN_vpaddd 0xe2d
#define MN_vpshldd 0xe34
#define MN_kandd 0xe3c
#define MN_vpandd 0xe42
#define MN_vpexpandd 0xe49
#define MN_vpblendd 0xe53
#define MN_vpgatherdd 0xe5c
#define MN_vpscatterdd 0xe67
#define MN_vpshrdd 0xe73
#define MN_vpmacsdd 0xe7b
#define MN_vpmacssdd 0xe84
#define MN_rdseed 0xe8e
#define MN_vpcomged 0xe95
#define MN_vpcomled 0xe9e
#define MN_vpcmpnled 0xea7
#define MN_vpcmpled 0xeb1
#define MN_tilestored 0xeba
#define MN_vpcomfalsed 0xec5
#define MN_vpcomtrued 0xed1
#define MN_pi2fd 0xedc
#define MN_pshufd (MN_vpshufd + 1)
#define MN_vpshufd 0xee2
#define MN_vpternlogd 0xeea
#define MN_pf2id 0xef5
#define MN_invpcid 0xefb
#define MN_rdpid 0xf03
#define MN_invvpid 0xf09
#define MN_cpuid 0xf11
#define MN_fbld 0xf17
#define MN_cld 0xf1c
#define MN_fld 0xf20
#define MN_shld (MN_vpshld + 2)
#define MN_vpshld 0xf24
#define MN_fild 0xf2b
#define MN_pslld (MN_vpslld + 1)
#define MN_vpslld 0xf30
#define MN_pmulld (MN_vpmulld + 1)
#define MN_vpmulld 0xf37
#define MN_vprold 0xf3f
#define MN_psrld (MN_vpsrld + 1)
#define MN_vpsrld 0xf46
#define MN_vmptrld 0xf4d
#define MN_kshiftld 0xf55
#define MN_enqcmd 0xf5e
#define MN_vpblendmd 0xf65
#define MN_vptestnmd 0xf6f
#define MN_vpcomd 0xf79
#define MN_vpermd 0xf80
#define MN_vptestmd 0xf87
#define MN_and (MN_aand + 1)
#define MN_aand 0xf90
#define MN_pand (MN_vpand + 1)
#define MN_vpand 0xf95
#define MN_rdrand 0xf9b
#define MN_bnd 0xfa2
#define MN_kandnd 0xfa6
#define MN_vpandnd 0xfad
#define MN_xend 0xfb5
#define MN_valignd 0xfba
#define MN_psignd (MN_vpsignd + 1)
#define MN_vpsignd 0xfc2
#define MN_bound 0xfca
#define MN_slod 0xfd0
#define MN_vfmaddsub231pd 0xfd5
#define MN_vfmsub231pd 0xfe4
#define MN_vfnmsub231pd 0xff0
#define MN_vfmsubadd231pd 0xffd
#define MN_vfmadd231pd 0x100c
#define MN_vfnmadd231pd 0x1018
#define MN_vfmaddsub132pd 0x1025
#define MN_vfmsub132pd 0x1034
#define MN_vfnmsub132pd 0x1040
#define MN_vfmsubadd132pd 0x104d
#define MN_vfmadd132pd 0x105c
#define MN_vfnmadd132pd 0x1068
#define MN_vcvtph2pd 0x1075
#define MN_vpermi2pd 0x107f
#define MN_cvtpi2pd 0x1089
#define MN_vpermil2pd 0x1092
#define MN_vexp2pd 0x109d
#define MN_cvtdq2pd (MN_vcvtdq2pd + 1)
#define MN_vcvtdq2pd 0x10a5
#define MN_vcvtudq2pd 0x10af
#define MN_vcvtqq2pd 0x10ba
#define MN_vcvtuqq2pd 0x10c4
#define MN_cvtps2pd (MN_vcvtps2pd + 1)
#define MN_vcvtps2pd 0x10cf
#define MN_vpermt2pd 0x10d9
#define MN_vfmaddsub213pd 0x10e3
#define MN_vfmsub213pd 0x10f2
#define MN_vfnmsub213pd 0x10fe
#define MN_vfmsubadd213pd 0x110b
#define MN_vfmadd213pd 0x111a
#define MN_vfnmadd213pd 0x1126
#define MN_vrcp14pd 0x1133
#define MN_vrsqrt14pd 0x113c
#define MN_vrcp28pd 0x1147
#define MN_vrsqrt28pd 0x1150
#define MN_movapd (MN_vmovapd + 1)
#define MN_vmovapd 0x115b
#define MN_pswapd 0x1163
#define MN_subpd (MN_addsubpd + 3)
#define MN_addsubpd (MN_vfmaddsubpd + 3)
#define MN_vfmaddsubpd 0x116a
#define MN_vaddsubpd 0x1176
#define MN_hsubpd (MN_vhsubpd + 1)
#define MN_vhsubpd 0x1180
#define MN_vfmsubpd 0x1188
#define MN_vfnmsubpd 0x1191
#define MN_vsubpd 0x119b
#define MN_vgatherpf0dpd 0x11a2
#define MN_vscatterpf0dpd 0x11b0
#define MN_vgatherpf1dpd 0x11bf
#define MN_vscatterpf1dpd 0x11cd
#define MN_addpd (MN_vfmsubaddpd + 6)
#define MN_vfmsubaddpd 0x11dc
#define MN_haddpd (MN_vhaddpd + 1)
#define MN_vhaddpd 0x11e8
#define MN_vfmaddpd 0x11f0
#define MN_vfnmaddpd 0x11f9
#define MN_vaddpd 0x1203
#define MN_andpd (MN_vexpandpd + 4)
#define MN_vexpandpd 0x120a
#define MN_vandpd 0x1214
#define MN_blendpd (MN_vblendpd + 1)
#define MN_vblendpd 0x121b
#define MN_roundpd (MN_vroundpd + 1)
#define MN_vroundpd 0x1224
#define MN_vgatherdpd 0x122d
#define MN_vscatterdpd 0x1238
#define MN_cmpunordpd (MN_vcmpunordpd + 1)
#define MN_vcmpunordpd 0x1244
#define MN_cmpordpd (MN_vcmpordpd + 1)
#define MN_vcmpordpd 0x1250
#define MN_vreducepd 0x125a
#define MN_vrangepd 0x1264
#define MN_vcmpngepd 0x126d
#define MN_vcmpgepd 0x1277
#define MN_vrndscalepd 0x1280
#define MN_cmpnlepd (MN_vcmpnlepd + 1)
#define MN_vcmpnlepd 0x128c
#define MN_cmplepd (MN_vcmplepd + 1)
#define MN_vcmplepd 0x1296
#define MN_vcmpfalsepd 0x129f
#define MN_vcmptruepd 0x12ab
#define MN_vscalefpd 0x12b6
#define MN_shufpd (MN_vshufpd + 1)
#define MN_vshufpd 0x12c0
#define MN_unpckhpd (MN_vunpckhpd + 1)
#define MN_vunpckhpd 0x12c8
#define MN_movhpd (MN_vmovhpd + 1)
#define MN_vmovhpd 0x12d2
#define MN_movmskpd (MN_vmovmskpd + 1)
#define MN_vmovmskpd 0x12da
#define MN_vpermilpd 0x12e4
#define MN_unpcklpd (MN_vunpcklpd + 1)
#define MN_vunpcklpd 0x12ee
#define MN_mulpd (MN_vmulpd + 1)
#define MN_vmulpd 0x12f8
#define MN_movlpd (MN_vmovlpd + 1)
#define MN_vmovlpd 0x12ff
#define MN_vpcmpd 0x1307
#define MN_vblendmpd 0x130e
#define MN_vfixupimmpd 0x1318
#define MN_vpermpd 0x1324
#define MN_andnpd (MN_vandnpd + 1)
#define MN_vandnpd 0x132c
#define MN_minpd (MN_vminpd + 1)
#define MN_vminpd 0x1334
#define MN_dppd (MN_vdppd + 1)
#define MN_vdppd 0x133b
#define MN_cmppd (MN_vcmppd + 1)
#define MN_vcmppd 0x1341
#define MN_vgetexppd 0x1348
#define MN_vgatherpf0qpd 0x1352
#define MN_vscatterpf0qpd 0x1360
#define MN_vgatherpf1qpd 0x136f
#define MN_vscatterpf1qpd 0x137d
#define MN_vcmpunord_qpd 0x138c
#define MN_vcmpord_qpd 0x139a
#define MN_cmpneqpd (MN_vcmpneqpd + 1)
#define MN_vcmpneqpd 0x13a6
#define MN_cmpeqpd (MN_vcmpeqpd + 1)
#define MN_vcmpeqpd 0x13b0
#define MN_vcmpge_oqpd 0x13b9
#define MN_vcmple_oqpd 0x13c5
#define MN_vcmpfalse_oqpd 0x13d1
#define MN_vcmpneq_oqpd 0x13e0
#define MN_vcmpeq_oqpd 0x13ed
#define MN_vcmpgt_oqpd 0x13f9
#define MN_vcmplt_oqpd 0x1405
#define MN_vgatherqpd 0x1411
#define MN_vscatterqpd 0x141c
#define MN_vcmpnge_uqpd 0x1428
#define MN_vcmpnle_uqpd 0x1435
#define MN_vcmptrue_uqpd 0x1442
#define MN_vcmpneq_uqpd 0x1450
#define MN_vcmpeq_uqpd 0x145d
#define MN_vcmpngt_uqpd 0x1469
#define MN_vcmpnlt_uqpd 0x1476
#define MN_orpd (MN_vorpd + 1)
#define MN_vorpd 0x1483
#define MN_xorpd (MN_vxorpd + 1)
#define MN_vxorpd 0x1489
#define MN_vcmpunord_spd 0x1490
#define MN_vcmpord_spd 0x149e
#define MN_vcmpge_ospd 0x14aa
#define MN_vcmple_ospd 0x14b6
#define MN_vcmpfalse_ospd 0x14c2
#define MN_vcmpneq_ospd 0x14d1
#define MN_vcmpeq_ospd 0x14de
#define MN_vcmpgt_ospd 0x14ea
#define MN_vcmplt_ospd 0x14f6
#define MN_vfpclasspd 0x1502
#define MN_incsspd 0x150d
#define MN_rdsspd 0x1515
#define MN_vcompresspd 0x151c
#define MN_vcmpnge_uspd 0x1528
#define MN_vcmpnle_uspd 0x1535
#define MN_vcmptrue_uspd 0x1542
#define MN_vcmpneq_uspd 0x1550
#define MN_vcmpeq_uspd 0x155d
#define MN_vcmpngt_uspd 0x1569
#define MN_vcmpnlt_uspd 0x1576
#define MN_vcmpngtpd 0x1583
#define MN_vcmpgtpd 0x158d
#define MN_cmpnltpd (MN_vcmpnltpd + 1)
#define MN_vcmpnltpd 0x1596
#define MN_cmpltpd (MN_vcmpltpd + 1)
#define MN_vcmpltpd 0x15a0
#define MN_vgetmantpd 0x15a9
#define MN_movntpd (MN_vmovntpd + 1)
#define MN_vmovntpd 0x15b4
#define MN_sqrtpd (MN_vsqrtpd + 1)
#define MN_vsqrtpd 0x15bd
#define MN_vtestpd 0x15c5
#define MN_movupd (MN_vmovupd + 1)
#define MN_vmovupd 0x15cd
#define MN_blendvpd (MN_vblendvpd + 1)
#define MN_vblendvpd 0x15d5
#define MN_divpd (MN_vdivpd + 1)
#define MN_vdivpd 0x15df
#define MN_vmaskmovpd 0x15e6
#define MN_maxpd (MN_vminmaxpd + 4)
#define MN_vminmaxpd 0x15f1
#define MN_vmaxpd 0x15fb
#define MN_vfrczpd 0x1602
#define MN_vpcomeqd 0x160a
#define MN_vpcomneqd 0x1613
#define MN_vpcmpneqd 0x161d
#define MN_pcmpeqd (MN_vpcmpeqd + 1)
#define MN_vpcmpeqd 0x1627
#define MN_vpgatherqd 0x1630
#define MN_vpscatterqd 0x163b
#define MN_vpmovusqd 0x1647
#define MN_vpmovsqd 0x1651
#define MN_vpmovqd 0x165a
#define MN_shrd 0x1662
#define MN_kord 0x1667
#define MN_kxnord 0x166c
#define MN_vpord 0x1673
#define MN_vprord 0x1679
#define MN_word (MN_aword + 1)
#define MN_aword 0x1680
#define MN_dword (MN_adword + 1)
#define MN_adword 0x1686
#define MN_kxord 0x168d
#define MN_vpxord 0x1693
#define MN_pinsrd (MN_vpinsrd + 1)
#define MN_vpinsrd 0x169a
#define MN_kshiftrd 0x16a2
#define MN_pextrd (MN_vpextrd + 1)
#define MN_vpextrd 0x16ab
#define MN_vfmsub231sd 0x16b3
#define MN_vfnmsub231sd 0x16bf
#define MN_vfmadd231sd 0x16cc
#define MN_vfnmadd231sd 0x16d8
#define MN_vfmsub132sd 0x16e5
#define MN_vfnmsub132sd 0x16f1
#define MN_vfmadd132sd 0x16fe
#define MN_vfnmadd132sd 0x170a
#define MN_vcvtsh2sd 0x1717
#define MN_cvtsi2sd (MN_vcvtsi2sd + 1)
#define MN_vcvtsi2sd 0x1721
#define MN_vcvtusi2sd 0x172b
#define MN_cvtss2sd (MN_vcvtss2sd + 1)
#define MN_vcvtss2sd 0x1736
#define MN_vfmsub213sd 0x1740
#define MN_vfnmsub213sd 0x174c
#define MN_vfmadd213sd 0x1759
#define MN_vfnmadd213sd 0x1765
#define MN_vrcp14sd 0x1772
#define MN_vrsqrt14sd 0x177b
#define MN_vrcp28sd 0x1786
#define MN_vrsqrt28sd 0x178f
#define MN_pabsd (MN_vpabsd + 1)
#define MN_vpabsd 0x179a
#define MN_subsd (MN_vfmsubsd + 3)
#define MN_vfmsubsd 0x17a1
#define MN_vfnmsubsd 0x17aa
#define MN_vsubsd 0x17b4
#define MN_addsd (MN_vfmaddsd + 3)
#define MN_vfmaddsd 0x17bb
#define MN_vfnmaddsd 0x17c4
#define MN_vaddsd 0x17ce
#define MN_roundsd (MN_vroundsd + 1)
#define MN_vroundsd 0x17d5
#define MN_cmpunordsd (MN_vcmpunordsd + 1)
#define MN_vcmpunordsd 0x17de
#define MN_cmpordsd (MN_vcmpordsd + 1)
#define MN_vcmpordsd 0x17ea
#define MN_vreducesd 0x17f4
#define MN_vrangesd 0x17fe
#define MN_vcmpngesd 0x1807
#define MN_vcmpgesd 0x1811
#define MN_vrndscalesd 0x181a
#define MN_cmpnlesd (MN_vcmpnlesd + 1)
#define MN_vcmpnlesd 0x1826
#define MN_cmplesd (MN_vcmplesd + 1)
#define MN_vcmplesd 0x1830
#define MN_vcmpfalsesd 0x1839
#define MN_vcmptruesd 0x1845
#define MN_vscalefsd 0x1850
#define MN_comisd (MN_ucomisd + 1)
#define MN_ucomisd (MN_vucomisd + 1)
#define MN_vucomisd 0x185a
#define MN_vcomisd 0x1863
#define MN_mulsd (MN_vmulsd + 1)
#define MN_vmulsd 0x186b
#define MN_vfixupimmsd 0x1872
#define MN_minsd (MN_pminsd + 1)
#define MN_pminsd (MN_vpminsd + 1)
#define MN_vpminsd 0x187e
#define MN_vminsd 0x1886
#define MN_cmpsd (MN_vcmpsd + 1)
#define MN_vcmpsd 0x188d
#define MN_vgetexpsd 0x1894
#define MN_vcmpunord_qsd 0x189e
#define MN_vcmpord_qsd 0x18ac
#define MN_cmpneqsd (MN_vcmpneqsd + 1)
#define MN_vcmpneqsd 0x18b8
#define MN_cmpeqsd (MN_vcmpeqsd + 1)
#define MN_vcmpeqsd 0x18c2
#define MN_vcmpge_oqsd 0x18cb
#define MN_vcmple_oqsd 0x18d7
#define MN_vcmpfalse_oqsd 0x18e3
#define MN_vcmpneq_oqsd 0x18f2
#define MN_vcmpeq_oqsd 0x18ff
#define MN_vcmpgt_oqsd 0x190b
#define MN_vcmplt_oqsd 0x1917
#define MN_vcmpnge_uqsd 0x1923
#define MN_vcmpnle_uqsd 0x1930
#define MN_vcmptrue_uqsd 0x193d
#define MN_vcmpneq_uqsd 0x194b
#define MN_vcmpeq_uqsd 0x1958
#define MN_vcmpngt_uqsd 0x1964
#define MN_vcmpnlt_uqsd 0x1971
#define MN_vcmpunord_ssd 0x197e
#define MN_vcmpord_ssd 0x198c
#define MN_vpdpbssd 0x1998
#define MN_tdpbssd 0x19a1
#define MN_vpcompressd 0x19a9
#define MN_vcmpge_ossd 0x19b5
#define MN_vcmple_ossd 0x19c1
#define MN_vcmpfalse_ossd 0x19cd
#define MN_vcmpneq_ossd 0x19dc
#define MN_vcmpeq_ossd 0x19e9
#define MN_vcmpgt_ossd 0x19f5
#define MN_vcmplt_ossd 0x1a01
#define MN_wrssd 0x1a0d
#define MN_vfpclasssd 0x1a13
#define MN_vcmpnge_ussd 0x1a1e
#define MN_vcmpnle_ussd 0x1a2b
#define MN_vcmptrue_ussd 0x1a38
#define MN_vcmpneq_ussd 0x1a46
#define MN_vcmpeq_ussd 0x1a53
#define MN_vcmpngt_ussd 0x1a5f
#define MN_vcmpnlt_ussd 0x1a6c
#define MN_wrussd 0x1a79
#define MN_vp4dpwssd 0x1a80
#define MN_vpdpwssd 0x1a8a
#define MN_vcmpngtsd 0x1a93
#define MN_vcmpgtsd 0x1a9d
#define MN_cmpnltsd (MN_vcmpnltsd + 1)
#define MN_vcmpnltsd 0x1aa6
#define MN_cmpltsd (MN_vcmpltsd + 1)
#define MN_vcmpltsd 0x1ab0
#define MN_vgetmantsd 0x1ab9
#define MN_movntsd 0x1ac4
#define MN_sqrtsd (MN_vsqrtsd + 1)
#define MN_vsqrtsd 0x1acc
#define MN_vbroadcastsd 0x1ad4
#define MN_vpdpbusd 0x1ae1
#define MN_tdpbusd 0x1aea
#define MN_vpdpwusd 0x1af2
#define MN_divsd (MN_vdivsd + 1)
#define MN_vdivsd 0x1afb
#define MN_movsd (MN_vmovsd + 1)
#define MN_vmovsd 0x1b02
#define MN_maxsd (MN_vminmaxsd + 4)
#define MN_vminmaxsd 0x1b09
#define MN_pmaxsd (MN_vpmaxsd + 1)
#define MN_vpmaxsd 0x1b13
#define MN_vmaxsd 0x1b1b
#define MN_vucomxsd 0x1b22
#define MN_vcomxsd 0x1b2b
#define MN_vfrczsd 0x1b33
#define MN_vp2intersectd 0x1b3b
#define MN_vpconflictd 0x1b49
#define MN_vpcomgtd 0x1b55
#define MN_pcmpgtd (MN_vpcmpgtd + 1)
#define MN_vpcmpgtd 0x1b5e
#define MN_cltd 0x1b67
#define MN_vpcomltd 0x1b6c
#define MN_vpcmpnltd 0x1b75
#define MN_vpcmpltd 0x1b7f
#define MN_vpopcntd 0x1b88
#define MN_vplzcntd 0x1b91
#define MN_knotd 0x1b9a
#define MN_vprotd 0x1ba0
#define MN_std (MN_vpbroadcastd + 9)
#define MN_vpbroadcastd 0x1ba7
#define MN_ktestd 0x1bb4
#define MN_kortestd 0x1bbb
#define MN_cwtd 0x1bc4
#define MN_vpcomgeud 0x1bc9
#define MN_vpcomleud 0x1bd3
#define MN_vpcmpnleud 0x1bdd
#define MN_vpcmpleud 0x1be8
#define MN_vpcomfalseud 0x1bf2
#define MN_vpcomtrueud 0x1bff
#define MN_vpcomud 0x1c0b
#define MN_pminud (MN_vpminud + 1)
#define MN_vpminud 0x1c13
#define MN_vpcmpud 0x1c1b
#define MN_vpcomequd 0x1c23
#define MN_vpcomnequd 0x1c2d
#define MN_vpcmpnequd 0x1c38
#define MN_vpcmpequd 0x1c43
#define MN_vpdpbsud 0x1c4d
#define MN_tdpbsud 0x1c56
#define MN_vpdpwsud 0x1c5e
#define MN_vpcomgtud 0x1c67
#define MN_vpcomltud 0x1c71
#define MN_vpcmpnltud 0x1c7b
#define MN_vpcmpltud 0x1c86
#define MN_vpdpbuud 0x1c90
#define MN_tdpbuud 0x1c99
#define MN_vpdpwuud 0x1ca1
#define MN_pmaxud (MN_vpmaxud + 1)
#define MN_vpmaxud 0x1caa
#define MN_vpsravd 0x1cb2
#define MN_vpshldvd 0x1cba
#define MN_vpshrdvd 0x1cc3
#define MN_vpsllvd 0x1ccc
#define MN_vprolvd 0x1cd4
#define MN_vpsrlvd 0x1cdc
#define MN_invd (MN_wbinvd + 2)
#define MN_wbinvd 0x1ce4
#define MN_wbnoinvd 0x1ceb
#define MN_movd (MN_kmovd + 1)
#define MN_kmovd (MN_vpmaskmovd + 5)
#define MN_vpmaskmovd 0x1cf4
#define MN_vmovd 0x1cff
#define MN_vprorvd 0x1d05
#define MN_vphsubwd 0x1d0d
#define MN_cwd 0x1d16
#define MN_vphaddwd 0x1d1a
#define MN_pmaddwd (MN_vpmaddwd + 1)
#define MN_vpmaddwd 0x1d23
#define MN_punpckhwd (MN_vpunpckhwd + 1)
#define MN_vpunpckhwd 0x1d2c
#define MN_kunpckwd 0x1d37
#define MN_punpcklwd (MN_vpunpcklwd + 1)
#define MN_vpunpcklwd 0x1d40
#define MN_vpmacswd 0x1d4b
#define MN_vpmadcswd 0x1d54
#define MN_vpmacsswd 0x1d5e
#define MN_vpmadcsswd 0x1d68
#define MN_vphadduwd 0x1d73
#define MN_pmovsxwd (MN_vpmovsxwd + 1)
#define MN_vpmovsxwd 0x1d7d
#define MN_pmovzxwd (MN_vpmovzxwd + 1)
#define MN_vpmovzxwd 0x1d87
#define MN_movsxd 0x1d91
#define MN_fldl2e 0x1d98
#define MN_jae 0x1d9f
#define MN_jnae 0x1da3
#define MN_ccmpnae 0x1da8
#define MN_setnae 0x1db0
#define MN_ctestnae 0x1db7
#define MN_setzunae 0x1dc0
#define MN_cmovnae (MN_fcmovnae + 1)
#define MN_fcmovnae (MN_cfcmovnae + 1)
#define MN_cfcmovnae 0x1dc9
#define MN_ccmpae 0x1dd3
#define MN_setae 0x1dda
#define MN_ctestae 0x1de0
#define MN_setzuae 0x1de8
#define MN_cmovae (MN_fcmovae + 1)
#define MN_fcmovae (MN_cfcmovae + 1)
#define MN_cfcmovae 0x1df0
#define MN_jbe 0x1df9
#define MN_jnbe 0x1dfd
#define MN_ccmpnbe 0x1e02
#define MN_setnbe 0x1e0a
#define MN_ctestnbe 0x1e11
#define MN_setzunbe 0x1e1a
#define MN_cmovnbe (MN_fcmovnbe + 1)
#define MN_fcmovnbe (MN_cfcmovnbe + 1)
#define MN_cfcmovnbe 0x1e23
#define MN_ccmpbe 0x1e2d
#define MN_setbe 0x1e34
#define MN_ctestbe 0x1e3a
#define MN_setzube 0x1e42
#define MN_movbe (MN_cmovbe + 1)
#define MN_cmovbe (MN_fcmovbe + 1)
#define MN_fcmovbe (MN_cfcmovbe + 1)
#define MN_cfcmovbe 0x1e4a
#define MN_lfence 0x1e53
#define MN_mfence 0x1e5a
#define MN_sfence 0x1e61
#define MN_cwde 0x1e68
#define MN_ffree 0x1e6d
#define MN_jge 0x1e73
#define MN_jnge 0x1e77
#define MN_ccmpnge 0x1e7c
#define MN_setnge 0x1e84
#define MN_ctestnge 0x1e8b
#define MN_setzunge 0x1e94
#define MN_cmovnge (MN_cfcmovnge + 2)
#define MN_cfcmovnge 0x1e9d
#define MN_ccmpge 0x1ea7
#define MN_pfcmpge 0x1eae
#define MN_setge 0x1eb6
#define MN_ctestge 0x1ebc
#define MN_setzuge 0x1ec4
#define MN_cmovge (MN_cfcmovge + 2)
#define MN_cfcmovge 0x1ecc
#define MN_je 0x1ed5
#define MN_fscale 0x1ed8
#define MN_jle 0x1edf
#define MN_jnle 0x1ee3
#define MN_ccmpnle 0x1ee8
#define MN_setnle 0x1ef0
#define MN_ctestnle 0x1ef7
#define MN_setzunle 0x1f00
#define MN_cmovnle (MN_cfcmovnle + 2)
#define MN_cfcmovnle 0x1f09
#define MN_ccmple 0x1f13
#define MN_setle 0x1f1a
#define MN_ctestle 0x1f20
#define MN_setzule 0x1f28
#define MN_cmovle (MN_cfcmovle + 2)
#define MN_cfcmovle 0x1f30
#define MN_vmresume 0x1f39
#define MN_jne 0x1f42
#define MN_repne 0x1f46
#define MN_ccmpne 0x1f4c
#define MN_loopne 0x1f53
#define MN_setne 0x1f5a
#define MN_ctestne 0x1f60
#define MN_setzune 0x1f68
#define MN_cmovne (MN_fcmovne + 1)
#define MN_fcmovne (MN_cfcmovne + 1)
#define MN_cfcmovne 0x1f70
#define MN_repe 0x1f79
#define MN_jpe 0x1f7e
#define MN_ccmpe 0x1f82
#define MN_loope 0x1f88
#define MN_setpe 0x1f8e
#define MN_setzupe 0x1f94
#define MN_cmovpe (MN_cfcmovpe + 2)
#define MN_cfcmovpe 0x1f9c
#define MN_cdqe 0x1fa5
#define MN_xacquire 0x1faa
#define MN_xstore 0x1fb3
#define MN_rdfsbase 0x1fba
#define MN_wrfsbase 0x1fc3
#define MN_rdgsbase 0x1fcc
#define MN_wrgsbase 0x1fd5
#define MN_tilerelease 0x1fde
#define MN_xrelease 0x1fea
#define MN_pause (MN_tpause + 1)
#define MN_tpause 0x1ff3
#define MN_pvalidate 0x1ffa
#define MN_rmpupdate 0x2004
#define MN_sete 0x200e
#define MN_vmwrite 0x2013
#define MN_ptwrite 0x201b
#define MN_cldemote 0x2023
#define MN_cteste 0x202c
#define MN_sha1nexte 0x2033
#define MN_setzue 0x203d
#define MN_leave 0x2044
#define MN_fsave 0x204a
#define MN_vmsave 0x2050
#define MN_fnsave 0x2057
#define MN_xsave (MN_fxsave + 1)
#define MN_fxsave 0x205e
#define MN_cmove (MN_fcmove + 1)
#define MN_fcmove (MN_cfcmove + 1)
#define MN_cfcmove 0x2065
#define MN_serialize 0x206d
#define MN_vmxoff 0x2077
#define MN_lahf 0x207e
#define MN_sahf 0x2083
#define MN_pushf 0x2088
#define MN_ccmpf 0x208e
#define MN_popf 0x2094
#define MN_bsf 0x2099
#define MN_retf 0x209d
#define MN_ctestf 0x20a2
#define MN_neg 0x20a9
#define MN_ldtilecfg 0x20ad
#define MN_sttilecfg 0x20b7
#define MN_xchg (MN_cmpxchg + 3)
#define MN_cmpxchg 0x20c1
#define MN_pconfig 0x20c9
#define MN_jg 0x20d1
#define MN_jng 0x20d4
#define MN_ccmpng 0x20d8
#define MN_xstore_rng 0x20df
#define MN_xstorerng 0x20ea
#define MN_setng 0x20f4
#define MN_ctestng 0x20fa
#define MN_setzung 0x2102
#define MN_cmovng (MN_cfcmovng + 2)
#define MN_cfcmovng 0x210a
#define MN_invlpg 0x2113
#define MN_ccmpg 0x211a
#define MN_setg 0x2120
#define MN_ctestg 0x2125
#define MN_setzug 0x212c
#define MN_cmovg (MN_cfcmovg + 2)
#define MN_cfcmovg 0x2133
#define MN_vmlaunch 0x213b
#define MN_prefetch 0x2144
#define MN_fxch 0x214d
#define MN_vfmaddsub231ph 0x2152
#define MN_vfmsub231ph 0x2161
#define MN_vfnmsub231ph 0x216d
#define MN_vfmsubadd231ph 0x217a
#define MN_vfmadd231ph 0x2189
#define MN_vfnmadd231ph 0x2195
#define MN_vfmaddsub132ph 0x21a2
#define MN_vfmsub132ph 0x21b1
#define MN_vfnmsub132ph 0x21bd
#define MN_vfmsubadd132ph 0x21ca
#define MN_vfmadd132ph 0x21d9
#define MN_vfnmadd132ph 0x21e5
#define MN_vcvthf82ph 0x21f2
#define MN_vcvtpd2ph 0x21fd
#define MN_vcvtdq2ph 0x2207
#define MN_vcvtudq2ph 0x2211
#define MN_vcvtqq2ph 0x221c
#define MN_vcvtuqq2ph 0x2226
#define MN_vcvtps2ph 0x2231
#define MN_vcvtw2ph 0x223b
#define MN_vcvtuw2ph 0x2244
#define MN_vfmaddsub213ph 0x224e
#define MN_vfmsub213ph 0x225d
#define MN_vfnmsub213ph 0x2269
#define MN_vfmsubadd213ph 0x2276
#define MN_vfmadd213ph 0x2285
#define MN_vfnmadd213ph 0x2291
#define MN_vsubph 0x229e
#define MN_vfcmaddcph 0x22a5
#define MN_vfmaddcph 0x22b0
#define MN_vfcmulcph 0x22ba
#define MN_vfmulcph 0x22c4
#define MN_vaddph 0x22cd
#define MN_vcmpunordph 0x22d4
#define MN_vcmpordph 0x22e0
#define MN_vreduceph 0x22ea
#define MN_vcmpngeph 0x22f4
#define MN_vcmpgeph 0x22fe
#define MN_vrndscaleph 0x2307
#define MN_vcmpnleph 0x2313
#define MN_vcmpleph 0x231d
#define MN_vcmpfalseph 0x2326
#define MN_vcmptrueph 0x2332
#define MN_vscalefph 0x233d
#define MN_vmulph 0x2347
#define MN_vminph 0x234e
#define MN_vrcpph 0x2355
#define MN_vcmpph 0x235c
#define MN_vgetexpph 0x2363
#define MN_vcmpunord_qph 0x236d
#define MN_vcmpord_qph 0x237b
#define MN_vcmpneqph 0x2387
#define MN_vcmpeqph 0x2391
#define MN_vcmpge_oqph 0x239a
#define MN_vcmple_oqph 0x23a6
#define MN_vcmpfalse_oqph 0x23b2
#define MN_vcmpneq_oqph 0x23c1
#define MN_vcmpeq_oqph 0x23ce
#define MN_vcmpgt_oqph 0x23da
#define MN_vcmplt_oqph 0x23e6
#define MN_vcmpnge_uqph 0x23f2
#define MN_vcmpnle_uqph 0x23ff
#define MN_vcmptrue_uqph 0x240c
#define MN_vcmpneq_uqph 0x241a
#define MN_vcmpeq_uqph 0x2427
#define MN_vcmpngt_uqph 0x2433
#define MN_vcmpnlt_uqph 0x2440
#define MN_vcmpunord_sph 0x244d
#define MN_vcmpord_sph 0x245b
#define MN_vcmpge_osph 0x2467
#define MN_vcmple_osph 0x2473
#define MN_vcmpfalse_osph 0x247f
#define MN_vcmpneq_osph 0x248e
#define MN_vcmpeq_osph 0x249b
#define MN_vcmpgt_osph 0x24a7
#define MN_vcmplt_osph 0x24b3
#define MN_vfpclassph 0x24bf
#define MN_vcmpnge_usph 0x24ca
#define MN_vcmpnle_usph 0x24d7
#define MN_vcmptrue_usph 0x24e4
#define MN_vcmpneq_usph 0x24f2
#define MN_vcmpeq_usph 0x24ff
#define MN_vcmpngt_usph 0x250b
#define MN_vcmpnlt_usph 0x2518
#define MN_vcmpngtph 0x2525
#define MN_vcmpgtph 0x252f
#define MN_vcmpnltph 0x2538
#define MN_vcmpltph 0x2542
#define MN_vgetmantph 0x254b
#define MN_vrsqrtph 0x2556
#define MN_vsqrtph 0x255f
#define MN_vdivph 0x2567
#define MN_vminmaxph 0x256e
#define MN_vmaxph 0x2578
#define MN_vpmacsdqh 0x257f
#define MN_vpmacssdqh 0x2589
#define MN_vfmsub231sh 0x2594
#define MN_vfnmsub231sh 0x25a0
#define MN_vfmadd231sh 0x25ad
#define MN_vfnmadd231sh 0x25b9
#define MN_vfmsub132sh 0x25c6
#define MN_vfnmsub132sh 0x25d2
#define MN_vfmadd132sh 0x25df
#define MN_vfnmadd132sh 0x25eb
#define MN_vcvtsd2sh 0x25f8
#define MN_vcvtsi2sh 0x2602
#define MN_vcvtusi2sh 0x260c
#define MN_vcvtss2sh 0x2617
#define MN_vfmsub213sh 0x2621
#define MN_vfnmsub213sh 0x262d
#define MN_vfmadd213sh 0x263a
#define MN_vfnmadd213sh 0x2646
#define MN_psmash 0x2653
#define MN_vsubsh 0x265a
#define MN_vfcmaddcsh 0x2661
#define MN_vfmaddcsh 0x266c
#define MN_vfcmulcsh 0x2676
#define MN_vfmulcsh 0x2680
#define MN_vaddsh 0x2689
#define MN_vcmpunordsh 0x2690
#define MN_vcmpordsh 0x269c
#define MN_vreducesh 0x26a6
#define MN_vcmpngesh 0x26b0
#define MN_vcmpgesh 0x26ba
#define MN_vrndscalesh 0x26c3
#define MN_vcmpnlesh 0x26cf
#define MN_vcmplesh 0x26d9
#define MN_vcmpfalsesh 0x26e2
#define MN_vcmptruesh 0x26ee
#define MN_vscalefsh 0x26f9
#define MN_vucomish 0x2703
#define MN_vcomish 0x270c
#define MN_vmulsh 0x2714
#define MN_vminsh 0x271b
#define MN_vrcpsh 0x2722
#define MN_vcmpsh 0x2729
#define MN_vgetexpsh 0x2730
#define MN_vcmpunord_qsh 0x273a
#define MN_vcmpord_qsh 0x2748
#define MN_vcmpneqsh 0x2754
#define MN_vcmpeqsh 0x275e
#define MN_vcmpge_oqsh 0x2767
#define MN_vcmple_oqsh 0x2773
#define MN_vcmpfalse_oqsh 0x277f
#define MN_vcmpneq_oqsh 0x278e
#define MN_vcmpeq_oqsh 0x279b
#define MN_vcmpgt_oqsh 0x27a7
#define MN_vcmplt_oqsh 0x27b3
#define MN_vcmpnge_uqsh 0x27bf
#define MN_vcmpnle_uqsh 0x27cc
#define MN_vcmptrue_uqsh 0x27d9
#define MN_vcmpneq_uqsh 0x27e7
#define MN_vcmpeq_uqsh 0x27f4
#define MN_vcmpngt_uqsh 0x2800
#define MN_vcmpnlt_uqsh 0x280d
#define MN_vcmpunord_ssh 0x281a
#define MN_vcmpord_ssh 0x2828
#define MN_vcmpge_ossh 0x2834
#define MN_vcmple_ossh 0x2840
#define MN_vcmpfalse_ossh 0x284c
#define MN_vcmpneq_ossh 0x285b
#define MN_vcmpeq_ossh 0x2868
#define MN_vcmpgt_ossh 0x2874
#define MN_vcmplt_ossh 0x2880
#define MN_vfpclasssh 0x288c
#define MN_vcmpnge_ussh 0x2897
#define MN_vcmpnle_ussh 0x28a4
#define MN_vcmptrue_ussh 0x28b1
#define MN_vcmpneq_ussh 0x28bf
#define MN_vcmpeq_ussh 0x28cc
#define MN_vcmpngt_ussh 0x28d8
#define MN_vcmpnlt_ussh 0x28e5
#define MN_vcmpngtsh 0x28f2
#define MN_vcmpgtsh 0x28fc
#define MN_vcmpnltsh 0x2905
#define MN_vcmpltsh 0x290f
#define MN_vgetmantsh 0x2918
#define MN_vrsqrtsh 0x2923
#define MN_vsqrtsh 0x292c
#define MN_clflush 0x2934
#define MN_push 0x293c
#define MN_vdivsh 0x2941
#define MN_vmovsh 0x2948
#define MN_vminmaxsh 0x294f
#define MN_vmaxsh 0x2959
#define MN_vucomxsh 0x2960
#define MN_vcomxsh 0x2969
#define MN_blci 0x2971
#define MN_clgi 0x2976
#define MN_stgi 0x297b
#define MN_bzhi 0x2980
#define MN_cli 0x2985
#define MN_fcomi 0x2989
#define MN_fucomi 0x298f
#define MN_feni 0x2996
#define MN_fneni 0x299b
#define MN_cvttpd2pi 0x29a1
#define MN_cvtpd2pi 0x29ab
#define MN_cvttps2pi 0x29b4
#define MN_cvtps2pi 0x29be
#define MN_fldpi 0x29c7
#define MN_senduipi 0x29cd
#define MN_fcompi 0x29d6
#define MN_fucompi 0x29dd
#define MN_movdiri 0x29e5
#define MN_pcmpestri (MN_vpcmpestri + 1)
#define MN_vpcmpestri 0x29ed
#define MN_pcmpistri (MN_vpcmpistri + 1)
#define MN_vpcmpistri 0x29f8
#define MN_cvttsd2si (MN_vcvttsd2si + 1)
#define MN_vcvttsd2si 0x2a03
#define MN_cvtsd2si (MN_vcvtsd2si + 1)
#define MN_vcvtsd2si 0x2a0e
#define MN_vcvttsh2si 0x2a18
#define MN_vcvtsh2si 0x2a23
#define MN_cvttss2si (MN_vcvttss2si + 1)
#define MN_vcvttss2si 0x2a2d
#define MN_cvtss2si (MN_vcvtss2si + 1)
#define MN_vcvtss2si 0x2a38
#define MN_fdisi 0x2a42
#define MN_fndisi 0x2a48
#define MN_blsi 0x2a4f
#define MN_vcvttsd2usi 0x2a54
#define MN_vcvtsd2usi 0x2a60
#define MN_vcvttsh2usi 0x2a6b
#define MN_vcvtsh2usi 0x2a77
#define MN_vcvttss2usi 0x2a82
#define MN_vcvtss2usi 0x2a8e
#define MN_movnti 0x2a99
#define MN_sti 0x2aa0
#define MN_clui 0x2aa4
#define MN_stui (MN_testui + 2)
#define MN_testui 0x2aa9
#define MN_notrack 0x2ab0
#define MN_lock 0x2ab8
#define MN_bndmk 0x2abd
#define MN_xresldtrk 0x2ac3
#define MN_xsusldtrk 0x2acd
#define MN_blcmsk 0x2ad7
#define MN_blsmsk 0x2ade
#define MN_tzmsk 0x2ae5
#define MN_sal 0x2aeb
#define MN_lwpval 0x2aef
#define MN_bndcl 0x2af6
#define MN_rcl 0x2afc
#define MN_shl 0x2b00
#define MN_jl 0x2b04
#define MN_aesdec256kl 0x2b07
#define MN_aesenc256kl 0x2b13
#define MN_aesdecwide256kl 0x2b1f
#define MN_aesencwide256kl 0x2b2f
#define MN_aesdec128kl 0x2b3f
#define MN_aesenc128kl 0x2b4b
#define MN_aesdecwide128kl 0x2b57
#define MN_aesencwide128kl 0x2b67
#define MN_call (MN_tdcall + 2)
#define MN_tdcall 0x2b77
#define MN_lcall 0x2b7e
#define MN_seamcall 0x2b84
#define MN_vmmcall 0x2b8d
#define MN_vmcall 0x2b95
#define MN_syscall 0x2b9c
#define MN_vzeroall 0x2ba4
#define MN_fildll 0x2bad
#define MN_blcfill 0x2bb4
#define MN_blsfill 0x2bbc
#define MN_fistpll 0x2bc4
#define MN_fisttpll 0x2bcc
#define MN_jnl 0x2bd5
#define MN_ccmpnl 0x2bd9
#define MN_setnl 0x2be0
#define MN_ctestnl 0x2be6
#define MN_setzunl 0x2bee
#define MN_cmovnl (MN_cfcmovnl + 2)
#define MN_cfcmovnl 0x2bf6
#define MN_rol 0x2bff
#define MN_ccmpl 0x2c03
#define MN_arpl 0x2c09
#define MN_vpmacsdql 0x2c0e
#define MN_vpmacssdql 0x2c18
#define MN_lsl 0x2c23
#define MN_movsl 0x2c27
#define MN_setl 0x2c2d
#define MN_ctestl 0x2c32
#define MN_cwtl 0x2c39
#define MN_mul (MN_fmul + 1)
#define MN_fmul (MN_pfmul + 1)
#define MN_pfmul 0x2c3e
#define MN_imul (MN_fimul + 1)
#define MN_fimul 0x2c44
#define MN_montmul 0x2c4a
#define MN_setzul 0x2c52
#define MN_cmovl (MN_cfcmovl + 2)
#define MN_cfcmovl 0x2c59
#define MN_vpmovb2m 0x2c61
#define MN_vpmovd2m 0x2c6a
#define MN_vpmovq2m 0x2c73
#define MN_vpmovw2m 0x2c7c
#define MN_aam 0x2c85
#define MN_fxam 0x2c89
#define MN_fprem 0x2c8e
#define MN_fcom 0x2c94
#define MN_ficom 0x2c99
#define MN_fucom 0x2c9f
#define MN_fsetpm 0x2ca5
#define MN_fnsetpm 0x2cac
#define MN_frstpm 0x2cb4
#define MN_vpperm 0x2cbb
#define MN_pcmpestrm (MN_vpcmpestrm + 1)
#define MN_vpcmpestrm 0x2cc2
#define MN_pcmpistrm (MN_vpcmpistrm + 1)
#define MN_vpcmpistrm 0x2ccd
#define MN_rsm 0x2cd8
#define MN_fpatan 0x2cdc
#define MN_fptan 0x2ce3
#define MN_bndcn 0x2ce9
#define MN_andn (MN_pandn + 1)
#define MN_pandn (MN_vpandn + 1)
#define MN_vpandn 0x2cef
#define MN_in (MN_xbegin + 4)
#define MN_xbegin 0x2cf6
#define MN_pfmin 0x2cfd
#define MN_fsin 0x2d03
#define MN_vmxon 0x2d08
#define MN_vmrun 0x2d0e
#define MN_jo 0x2d14
#define MN_jno 0x2d17
#define MN_ccmpno 0x2d1b
#define MN_setno 0x2d22
#define MN_ctestno 0x2d28
#define MN_setzuno 0x2d30
#define MN_cmovno (MN_cfcmovno + 2)
#define MN_cfcmovno 0x2d38
#define MN_jpo 0x2d41
#define MN_ccmpo 0x2d45
#define MN_setpo 0x2d4b
#define MN_setzupo 0x2d51
#define MN_cmovpo (MN_cfcmovpo + 2)
#define MN_cfcmovpo 0x2d59
#define MN_cqo 0x2d62
#define MN_tilezero 0x2d66
#define MN_clzero 0x2d6f
#define MN_seto 0x2d76
#define MN_into 0x2d7b
#define MN_cqto 0x2d80
#define MN_ctesto 0x2d85
#define MN_ssto 0x2d8c
#define MN_setzuo 0x2d91
#define MN_cmovo (MN_cfcmovo + 2)
#define MN_cfcmovo 0x2d98
#define MN_push2p 0x2da0
#define MN_pop2p 0x2da7
#define MN_bswap 0x2dad
#define MN_fsubp 0x2db3
#define MN_pfrcp 0x2db9
#define MN_rdtscp 0x2dbf
#define MN_faddp 0x2dc6
#define MN_pdep 0x2dcc
#define MN_ffreep 0x2dd1
#define MN_rep 0x2dd8
#define MN_pushp 0x2ddc
#define MN_fcomip 0x2de2
#define MN_fucomip 0x2de9
#define MN_jp 0x2df1
#define MN_fmulp 0x2df4
#define MN_cmp (MN_scmp + 1)
#define MN_scmp 0x2dfa
#define MN_jmp (MN_ljmp + 1)
#define MN_ljmp 0x2dff
#define MN_fcomp 0x2e04
#define MN_ficomp 0x2e0a
#define MN_fucomp 0x2e11
#define MN_jnp 0x2e18
#define MN_setnp 0x2e1c
#define MN_setzunp 0x2e22
#define MN_cmovnp (MN_cfcmovnp + 2)
#define MN_cfcmovnp 0x2e2a
#define MN_nop (MN_fnop + 1)
#define MN_fnop 0x2e33
#define MN_loop 0x2e38
#define MN_pop 0x2e3d
#define MN_fcompp 0x2e41
#define MN_fucompp 0x2e48
#define MN_popp 0x2e50
#define MN_fsubrp 0x2e55
#define MN_fdivrp 0x2e5c
#define MN_rstorssp 0x2e63
#define MN_saveprevssp 0x2e6c
#define MN_setp 0x2e78
#define MN_fbstp 0x2e7d
#define MN_fdecstp 0x2e83
#define MN_fincstp 0x2e8b
#define MN_fstp 0x2e93
#define MN_fistp 0x2e98
#define MN_fisttp 0x2e9e
#define MN_movddup (MN_vmovddup + 1)
#define MN_vmovddup 0x2ea5
#define MN_movshdup (MN_vmovshdup + 1)
#define MN_vmovshdup 0x2eae
#define MN_movsldup (MN_vmovsldup + 1)
#define MN_vmovsldup 0x2eb8
#define MN_setzup 0x2ec2
#define MN_fdivp 0x2ec9
#define MN_cmovp (MN_cfcmovp + 2)
#define MN_cfcmovp 0x2ecf
#define MN_vpbroadcastmb2q 0x2ed7
#define MN_vpermi2q 0x2ee7
#define MN_vpmovm2q 0x2ef0
#define MN_movdq2q 0x2ef9
#define MN_vpermt2q 0x2f01
#define MN_vpshaq 0x2f0a
#define MN_vpsraq 0x2f11
#define MN_vphaddbq 0x2f18
#define MN_vphaddubq 0x2f21
#define MN_psubq (MN_vpsubq + 1)
#define MN_vpsubq 0x2f2b
#define MN_pmovsxbq (MN_vpmovsxbq + 1)
#define MN_vpmovsxbq 0x2f32
#define MN_pmovzxbq (MN_vpmovzxbq + 1)
#define MN_vpmovzxbq 0x2f3c
#define MN_cvttpd2dq (MN_vcvttpd2dq + 1)
#define MN_vcvttpd2dq 0x2f46
#define MN_cvtpd2dq (MN_vcvtpd2dq + 1)
#define MN_vcvtpd2dq 0x2f51
#define MN_vcvttph2dq 0x2f5b
#define MN_vcvtph2dq 0x2f66
#define MN_movq2dq 0x2f70
#define MN_cvttps2dq (MN_vcvttps2dq + 1)
#define MN_vcvttps2dq 0x2f78
#define MN_cvtps2dq (MN_vcvtps2dq + 1)
#define MN_vcvtps2dq 0x2f83
#define MN_vphsubdq 0x2f8d
#define MN_cdq 0x2f96
#define MN_kaddq 0x2f9a
#define MN_paddq (MN_vpaddq + 1)
#define MN_vpaddq 0x2fa0
#define MN_vphadddq 0x2fa7
#define MN_punpckhdq (MN_vpunpckhdq + 1)
#define MN_vpunpckhdq 0x2fb0
#define MN_kunpckdq 0x2fbb
#define MN_vpshldq 0x2fc4
#define MN_punpckldq (MN_vpunpckldq + 1)
#define MN_vpunpckldq 0x2fcc
#define MN_pslldq (MN_vpslldq + 1)
#define MN_vpslldq 0x2fd7
#define MN_psrldq (MN_vpsrldq + 1)
#define MN_vpsrldq 0x2fdf
#define MN_pmuldq (MN_vpmuldq + 1)
#define MN_vpmuldq 0x2fe7
#define MN_kandq 0x2fef
#define MN_vpandq 0x2ff5
#define MN_vpexpandq 0x2ffc
#define MN_punpckhqdq (MN_vpunpckhqdq + 1)
#define MN_vpunpckhqdq 0x3006
#define MN_pclmulhqhqdq (MN_vpclmulhqhqdq + 1)
#define MN_vpclmulhqhqdq 0x3012
#define MN_pclmullqhqdq (MN_vpclmullqhqdq + 1)
#define MN_vpclmullqhqdq 0x3020
#define MN_punpcklqdq (MN_vpunpcklqdq + 1)
#define MN_vpunpcklqdq 0x302e
#define MN_pclmulhqlqdq (MN_vpclmulhqlqdq + 1)
#define MN_vpclmulhqlqdq 0x303a
#define MN_pclmullqlqdq (MN_vpclmullqlqdq + 1)
#define MN_vpclmullqlqdq 0x3048
#define MN_pclmulqdq (MN_vpclmulqdq + 1)
#define MN_vpclmulqdq 0x3056
#define MN_vpgatherdq 0x3061
#define MN_vpscatterdq 0x306c
#define MN_vpshrdq 0x3078
#define MN_movntdq (MN_vmovntdq + 1)
#define MN_vmovntdq 0x3080
#define MN_vcvttpd2udq 0x3089
#define MN_vcvtpd2udq 0x3095
#define MN_vcvttph2udq 0x30a0
#define MN_vcvtph2udq 0x30ac
#define MN_vcvttps2udq 0x30b7
#define MN_vcvtps2udq 0x30c3
#define MN_vphaddudq 0x30ce
#define MN_pmuludq (MN_vpmuludq + 1)
#define MN_vpmuludq 0x30d8
#define MN_pmovsxdq (MN_vpmovsxdq + 1)
#define MN_vpmovsxdq 0x30e1
#define MN_pmovzxdq (MN_vpmovzxdq + 1)
#define MN_vpmovzxdq 0x30eb
#define MN_vpcomgeq 0x30f5
#define MN_vpcomleq 0x30fe
#define MN_vpcmpnleq 0x3107
#define MN_vpcmpleq 0x3111
#define MN_pfcmpeq 0x311a
#define MN_vpcomfalseq 0x3122
#define MN_vpcomtrueq 0x312e
#define MN_vpternlogq 0x3139
#define MN_vpshlq 0x3144
#define MN_psllq (MN_vpsllq + 1)
#define MN_vpsllq 0x314b
#define MN_vpmullq 0x3152
#define MN_vprolq 0x315a
#define MN_psrlq (MN_vpsrlq + 1)
#define MN_vpsrlq 0x3161
#define MN_kshiftlq 0x3168
#define MN_vpblendmq 0x3171
#define MN_vptestnmq 0x317b
#define MN_vpcomq 0x3185
#define MN_vpermq 0x318c
#define MN_vptestmq 0x3193
#define MN_kandnq 0x319c
#define MN_vpandnq 0x31a3
#define MN_valignq 0x31ab
#define MN_vpcmpq 0x31b3
#define MN_incsspq 0x31ba
#define MN_rdsspq 0x31c2
#define MN_vcvttpd2qq 0x31c9
#define MN_vcvtpd2qq 0x31d4
#define MN_vcvttph2qq 0x31de
#define MN_vcvtph2qq 0x31e9
#define MN_vcvttps2qq 0x31f3
#define MN_vcvtps2qq 0x31fe
#define MN_vpcomeqq 0x3208
#define MN_vpcomneqq 0x3211
#define MN_vpcmpneqq 0x321b
#define MN_pcmpeqq (MN_vpcmpeqq + 1)
#define MN_vpcmpeqq 0x3225
#define MN_vpgatherqq 0x322e
#define MN_vpscatterqq 0x3239
#define MN_vcvttpd2uqq 0x3245
#define MN_vcvtpd2uqq 0x3251
#define MN_vcvttph2uqq 0x325c
#define MN_vcvtph2uqq 0x3268
#define MN_vcvttps2uqq 0x3273
#define MN_vcvtps2uqq 0x327f
#define MN_korq 0x328a
#define MN_kxnorq 0x328f
#define MN_vporq 0x3296
#define MN_vprorq 0x329c
#define MN_kxorq 0x32a3
#define MN_vpxorq 0x32a9
#define MN_pinsrq (MN_vpinsrq + 1)
#define MN_vpinsrq 0x32b0
#define MN_kshiftrq 0x32b8
#define MN_extrq (MN_pextrq + 1)
#define MN_pextrq (MN_vpextrq + 1)
#define MN_vpextrq 0x32c1
#define MN_vpabsq 0x32c9
#define MN_vpminsq 0x32d0
#define MN_vpcompressq 0x32d8
#define MN_wrssq 0x32e4
#define MN_wrussq 0x32ea
#define MN_vpmaxsq 0x32f1
#define MN_vp2intersectq 0x32f9
#define MN_vpconflictq 0x3307
#define MN_vpcomgtq 0x3313
#define MN_pcmpgtq (MN_vpcmpgtq + 1)
#define MN_vpcmpgtq 0x331c
#define MN_cltq 0x3325
#define MN_vpcomltq 0x332a
#define MN_vpcmpnltq 0x3333
#define MN_vpcmpltq 0x333d
#define MN_vpopcntq 0x3346
#define MN_vplzcntq 0x334f
#define MN_movntq 0x3358
#define MN_knotq 0x335f
#define MN_vprotq 0x3365
#define MN_insertq 0x336c
#define MN_vpbroadcastq 0x3374
#define MN_ktestq 0x3381
#define MN_kortestq 0x3388
#define MN_vpcomgeuq 0x3391
#define MN_vpcomleuq 0x339b
#define MN_vpcmpnleuq 0x33a5
#define MN_vpcmpleuq 0x33b0
#define MN_vpcomfalseuq 0x33ba
#define MN_vpcomtrueuq 0x33c7
#define MN_vpmadd52huq 0x33d3
#define MN_vpmadd52luq 0x33df
#define MN_vpcomuq 0x33eb
#define MN_vpminuq 0x33f3
#define MN_vpcmpuq 0x33fb
#define MN_vpcomequq 0x3403
#define MN_vpcomnequq 0x340d
#define MN_vpcmpnequq 0x3418
#define MN_vpcmpequq 0x3423
#define MN_vpcomgtuq 0x342d
#define MN_vpcomltuq 0x3437
#define MN_vpcmpnltuq 0x3441
#define MN_vpcmpltuq 0x344c
#define MN_vpmaxuq 0x3456
#define MN_vpsravq 0x345e
#define MN_vpshldvq 0x3466
#define MN_vpshrdvq 0x346f
#define MN_vpsllvq 0x3478
#define MN_vprolvq 0x3480
#define MN_vpsrlvq 0x3488
#define MN_movq (MN_kmovq + 1)
#define MN_kmovq (MN_maskmovq + 3)
#define MN_maskmovq (MN_vpmaskmovq + 2)
#define MN_vpmaskmovq 0x3490
#define MN_vmovq 0x349b
#define MN_vprorvq 0x34a1
#define MN_vphaddwq 0x34a9
#define MN_vphadduwq 0x34b2
#define MN_pmovsxwq (MN_vpmovsxwq + 1)
#define MN_vpmovsxwq 0x34bc
#define MN_pmovzxwq (MN_vpmovzxwq + 1)
#define MN_vpmovzxwq 0x34c6
#define MN_rex_r 0x34d0
#define MN_vmclear 0x34d6
#define MN_lar 0x34de
#define MN_sar 0x34e2
#define MN_fsubr (MN_pfsubr + 1)
#define MN_pfsubr 0x34e6
#define MN_fisubr 0x34ed
#define MN_rcr 0x34f4
#define MN_vzeroupper 0x34f8
#define MN_enter (MN_sysenter + 3)
#define MN_sysenter 0x3503
#define MN_shr 0x350c
#define MN_clr 0x3510
#define MN_palignr (MN_vpalignr + 1)
#define MN_vpalignr 0x3514
#define MN_or (MN_aor + 1)
#define MN_aor 0x351d
#define MN_por (MN_vpor + 1)
#define MN_vpor 0x3521
#define MN_ror 0x3526
#define MN_monitor (MN_umonitor + 1)
#define MN_umonitor 0x352a
#define MN_frstor 0x3533
#define MN_xrstor (MN_fxrstor + 1)
#define MN_fxrstor 0x353a
#define MN_xor (MN_axor + 1)
#define MN_axor 0x3542
#define MN_pxor (MN_vpxor + 1)
#define MN_vpxor 0x3547
#define MN_verr 0x354d
#define MN_bsr 0x3552
#define MN_ldmxcsr (MN_vldmxcsr + 1)
#define MN_vldmxcsr 0x3556
#define MN_stmxcsr (MN_vstmxcsr + 1)
#define MN_vstmxcsr 0x355f
#define MN_blsr 0x3568
#define MN_rdmsr (MN_urdmsr + 1)
#define MN_urdmsr 0x356d
#define MN_wrmsr (MN_uwrmsr + 1)
#define MN_uwrmsr 0x3574
#define MN_btr 0x357b
#define MN_xcrypt_ctr 0x357f
#define MN_xcryptctr 0x358a
#define MN_ltr 0x3594
#define MN_str 0x3598
#define MN_bextr 0x359c
#define MN_fdivr 0x35a2
#define MN_fidivr 0x35a8
#define MN_rex_wr 0x35af
#define MN_vcvtne2ph2bf8s 0x35b6
#define MN_vcvtneph2bf8s 0x35c5
#define MN_vcvtbiasph2bf8s 0x35d3
#define MN_vcvtne2ph2hf8s 0x35e3
#define MN_vcvtneph2hf8s 0x35f2
#define MN_vcvtbiasph2hf8s 0x3600
#define MN_aas 0x3610
#define MN_scas 0x3614
#define MN_das 0x3619
#define MN_fabs 0x361d
#define MN_jmpabs 0x3622
#define MN_movabs 0x3629
#define MN_vcvtnebf162ibs 0x3630
#define MN_vcvttbf162ibs 0x363f
#define MN_vcvttph2ibs 0x364d
#define MN_vcvtph2ibs 0x3659
#define MN_vcvttps2ibs 0x3664
#define MN_vcvtps2ibs 0x3670
#define MN_vcvtnebf162iubs 0x367b
#define MN_vcvttbf162iubs 0x368b
#define MN_vcvttph2iubs 0x369a
#define MN_vcvtph2iubs 0x36a7
#define MN_vcvttps2iubs 0x36b3
#define MN_vcvtps2iubs 0x36c0
#define MN_cs (MN_blcs + 2)
#define MN_blcs 0x36cc
#define MN_ds (MN_lds + 1)
#define MN_lds 0x36d1
#define MN_enqcmds 0x36d5
#define MN_lods 0x36dd
#define MN_vpdpbssds 0x36e2
#define MN_vp4dpwssds 0x36ec
#define MN_vpdpwssds 0x36f7
#define MN_vpdpbusds 0x3701
#define MN_vpdpwusds 0x370b
#define MN_vpdpbsuds 0x3715
#define MN_vpdpwsuds 0x371f
#define MN_vpdpbuuds 0x3729
#define MN_vpdpwuuds 0x3733
#define MN_es (MN_les + 1)
#define MN_les 0x373d
#define MN_xsaves 0x3741
#define MN_fs (MN_lfs + 1)
#define MN_lfs 0x3748
#define MN_gs (MN_lkgs + 2)
#define MN_lkgs 0x374c
#define MN_lgs 0x3751
#define MN_swapgs 0x3755
#define MN_fchs 0x375c
#define MN_vcvttsd2sis 0x3761
#define MN_vcvttss2sis 0x376d
#define MN_vcvttsd2usis 0x3779
#define MN_vcvttss2usis 0x3786
#define MN_js 0x3793
#define MN_encls 0x3796
#define MN_emms (MN_femms + 1)
#define MN_femms 0x379c
#define MN_ins (MN_lwpins + 3)
#define MN_lwpins 0x37a2
#define MN_jns 0x37a9
#define MN_ccmpns 0x37ad
#define MN_wrmsrns 0x37b4
#define MN_setns 0x37bc
#define MN_ctestns 0x37c2
#define MN_setzuns 0x37ca
#define MN_cmovns (MN_cfcmovns + 2)
#define MN_cfcmovns 0x37d2
#define MN_fcos 0x37db
#define MN_fsincos 0x37e0
#define MN_stos 0x37e8
#define MN_vfmaddsub231ps 0x37ed
#define MN_vfmsub231ps 0x37fc
#define MN_vfnmsub231ps 0x3808
#define MN_vfmsubadd231ps 0x3815
#define MN_vfmadd231ps 0x3824
#define MN_vfnmadd231ps 0x3830
#define MN_vfmaddsub132ps 0x383d
#define MN_vfmsub132ps 0x384c
#define MN_vfnmsub132ps 0x3858
#define MN_vfmsubadd132ps 0x3865
#define MN_vfmadd132ps 0x3874
#define MN_vfnmadd132ps 0x3880
#define MN_vcvtneebf162ps 0x388d
#define MN_vbcstnebf162ps 0x389c
#define MN_vcvtneobf162ps 0x38ab
#define MN_cvtpd2ps (MN_vcvtpd2ps + 1)
#define MN_vcvtpd2ps 0x38ba
#define MN_vcvtneeph2ps 0x38c4
#define MN_vcvtneoph2ps 0x38d1
#define MN_vcvtph2ps 0x38de
#define MN_vbcstnesh2ps 0x38e8
#define MN_vpermi2ps 0x38f5
#define MN_cvtpi2ps 0x38ff
#define MN_vpermil2ps 0x3908
#define MN_vexp2ps 0x3913
#define MN_cvtdq2ps (MN_vcvtdq2ps + 1)
#define MN_vcvtdq2ps 0x391b
#define MN_vcvtudq2ps 0x3925
#define MN_vcvtqq2ps 0x3930
#define MN_vcvtuqq2ps 0x393a
#define MN_vpermt2ps 0x3945
#define MN_vfmaddsub213ps 0x394f
#define MN_vfmsub213ps 0x395e
#define MN_vfnmsub213ps 0x396a
#define MN_vfmsubadd213ps 0x3977
#define MN_vfmadd213ps 0x3986
#define MN_vfnmadd213ps 0x3992
#define MN_vrcp14ps 0x399f
#define MN_vrsqrt14ps 0x39a8
#define MN_tdpbf16ps 0x39b3
#define MN_vdpbf16ps 0x39bd
#define MN_tcmmrlfp16ps 0x39c7
#define MN_tcmmimfp16ps 0x39d4
#define MN_tdpfp16ps 0x39e1
#define MN_vrcp28ps 0x39eb
#define MN_vrsqrt28ps 0x39f4
#define MN_movaps (MN_vmovaps + 1)
#define MN_vmovaps 0x39ff
#define MN_subps (MN_addsubps + 3)
#define MN_addsubps (MN_vfmaddsubps + 3)
#define MN_vfmaddsubps 0x3a07
#define MN_vaddsubps 0x3a13
#define MN_hsubps (MN_vhsubps + 1)
#define MN_vhsubps 0x3a1d
#define MN_vfmsubps 0x3a25
#define MN_vfnmsubps 0x3a2e
#define MN_vsubps 0x3a38
#define MN_vgatherpf0dps 0x3a3f
#define MN_vscatterpf0dps 0x3a4d
#define MN_vgatherpf1dps 0x3a5c
#define MN_vscatterpf1dps 0x3a6a
#define MN_addps (MN_vfmsubaddps + 6)
#define MN_vfmsubaddps 0x3a79
#define MN_haddps (MN_vhaddps + 1)
#define MN_vhaddps 0x3a85
#define MN_v4fmaddps 0x3a8d
#define MN_vfmaddps 0x3a97
#define MN_v4fnmaddps 0x3aa0
#define MN_vfnmaddps 0x3aab
#define MN_vaddps 0x3ab5
#define MN_andps (MN_vexpandps + 4)
#define MN_vexpandps 0x3abc
#define MN_vandps 0x3ac6
#define MN_blendps (MN_vblendps + 1)
#define MN_vblendps 0x3acd
#define MN_roundps (MN_vroundps + 1)
#define MN_vroundps 0x3ad6
#define MN_vgatherdps 0x3adf
#define MN_vscatterdps 0x3aea
#define MN_cmpunordps (MN_vcmpunordps + 1)
#define MN_vcmpunordps 0x3af6
#define MN_cmpordps (MN_vcmpordps + 1)
#define MN_vcmpordps 0x3b02
#define MN_vreduceps 0x3b0c
#define MN_vrangeps 0x3b16
#define MN_vcmpngeps 0x3b1f
#define MN_vcmpgeps 0x3b29
#define MN_vrndscaleps 0x3b32
#define MN_cmpnleps (MN_vcmpnleps + 1)
#define MN_vcmpnleps 0x3b3e
#define MN_cmpleps (MN_vcmpleps + 1)
#define MN_vcmpleps 0x3b48
#define MN_vcmpfalseps 0x3b51
#define MN_vcmptrueps 0x3b5d
#define MN_vscalefps 0x3b68
#define MN_shufps (MN_vshufps + 1)
#define MN_vshufps 0x3b72
#define MN_unpckhps (MN_vunpckhps + 1)
#define MN_vunpckhps 0x3b7a
#define MN_movlhps (MN_vmovlhps + 1)
#define MN_vmovlhps 0x3b84
#define MN_vdpphps 0x3b8d
#define MN_movhps (MN_vmovhps + 1)
#define MN_vmovhps 0x3b95
#define MN_movmskps (MN_vmovmskps + 1)
#define MN_vmovmskps 0x3b9d
#define MN_movhlps (MN_vmovhlps + 1)
#define MN_vmovhlps 0x3ba7
#define MN_vpermilps 0x3bb0
#define MN_unpcklps (MN_vunpcklps + 1)
#define MN_vunpcklps 0x3bba
#define MN_mulps (MN_vmulps + 1)
#define MN_vmulps 0x3bc4
#define MN_movlps (MN_vmovlps + 1)
#define MN_vmovlps 0x3bcb
#define MN_cmps (MN_ccmps + 1)
#define MN_ccmps 0x3bd3
#define MN_vblendmps 0x3bd9
#define MN_vfixupimmps 0x3be3
#define MN_vpermps 0x3bef
#define MN_andnps (MN_vandnps + 1)
#define MN_vandnps 0x3bf7
#define MN_minps (MN_vminps + 1)
#define MN_vminps 0x3bff
#define MN_seamops 0x3c06
#define MN_rcpps (MN_vrcpps + 1)
#define MN_vrcpps 0x3c0e
#define MN_dpps (MN_vdpps + 1)
#define MN_vdpps 0x3c15
#define MN_cmpps (MN_vcmpps + 1)
#define MN_vcmpps 0x3c1b
#define MN_vgetexpps 0x3c22
#define MN_vgatherpf0qps 0x3c2c
#define MN_vscatterpf0qps 0x3c3a
#define MN_vgatherpf1qps 0x3c49
#define MN_vscatterpf1qps 0x3c57
#define MN_vcmpunord_qps 0x3c66
#define MN_vcmpord_qps 0x3c74
#define MN_cmpneqps (MN_vcmpneqps + 1)
#define MN_vcmpneqps 0x3c80
#define MN_cmpeqps (MN_vcmpeqps + 1)
#define MN_vcmpeqps 0x3c8a
#define MN_vcmpge_oqps 0x3c93
#define MN_vcmple_oqps 0x3c9f
#define MN_vcmpfalse_oqps 0x3cab
#define MN_vcmpneq_oqps 0x3cba
#define MN_vcmpeq_oqps 0x3cc7
#define MN_vcmpgt_oqps 0x3cd3
#define MN_vcmplt_oqps 0x3cdf
#define MN_vgatherqps 0x3ceb
#define MN_vscatterqps 0x3cf6
#define MN_vcmpnge_uqps 0x3d02
#define MN_vcmpnle_uqps 0x3d0f
#define MN_vcmptrue_uqps 0x3d1c
#define MN_vcmpneq_uqps 0x3d2a
#define MN_vcmpeq_uqps 0x3d37
#define MN_vcmpngt_uqps 0x3d43
#define MN_vcmpnlt_uqps 0x3d50
#define MN_orps (MN_vorps + 1)
#define MN_vorps 0x3d5d
#define MN_xorps (MN_vxorps + 1)
#define MN_vxorps 0x3d63
#define MN_vcmpunord_sps 0x3d6a
#define MN_vcmpord_sps 0x3d78
#define MN_vcmpge_osps 0x3d84
#define MN_vcmple_osps 0x3d90
#define MN_vcmpfalse_osps 0x3d9c
#define MN_vcmpneq_osps 0x3dab
#define MN_vcmpeq_osps 0x3db8
#define MN_vcmpgt_osps 0x3dc4
#define MN_vcmplt_osps 0x3dd0
#define MN_vfpclassps 0x3ddc
#define MN_vcompressps 0x3de7
#define MN_vcmpnge_usps 0x3df3
#define MN_vcmpnle_usps 0x3e00
#define MN_vcmptrue_usps 0x3e0d
#define MN_vcmpneq_usps 0x3e1b
#define MN_vcmpeq_usps 0x3e28
#define MN_vcmpngt_usps 0x3e34
#define MN_vcmpnlt_usps 0x3e41
#define MN_extractps (MN_vextractps + 1)
#define MN_vextractps 0x3e4e
#define MN_vcmpngtps 0x3e59
#define MN_vcmpgtps 0x3e63
#define MN_cmpnltps (MN_vcmpnltps + 1)
#define MN_vcmpnltps 0x3e6c
#define MN_cmpltps (MN_vcmpltps + 1)
#define MN_vcmpltps 0x3e76
#define MN_vgetmantps 0x3e7f
#define MN_movntps (MN_vmovntps + 1)
#define MN_vmovntps 0x3e8a
#define MN_insertps (MN_vinsertps + 1)
#define MN_vinsertps 0x3e93
#define MN_sqrtps (MN_rsqrtps + 1)
#define MN_rsqrtps (MN_vrsqrtps + 1)
#define MN_vrsqrtps 0x3e9d
#define MN_vsqrtps 0x3ea6
#define MN_vtestps 0x3eae
#define MN_movups (MN_vmovups + 1)
#define MN_vmovups 0x3eb6
#define MN_blendvps (MN_vblendvps + 1)
#define MN_vblendvps 0x3ebe
#define MN_divps (MN_vdivps + 1)
#define MN_vdivps 0x3ec8
#define MN_vmaskmovps 0x3ecf
#define MN_maxps (MN_vminmaxps + 4)
#define MN_vminmaxps 0x3eda
#define MN_vmaxps 0x3ee4
#define MN_vfrczps 0x3eeb
#define MN_vcvttpd2dqs 0x3ef3
#define MN_vcvttps2dqs 0x3eff
#define MN_vcvttpd2udqs 0x3f0b
#define MN_vcvttps2udqs 0x3f18
#define MN_vcvttpd2qqs 0x3f25
#define MN_vcvttps2qqs 0x3f31
#define MN_vcvttpd2uqqs 0x3f3d
#define MN_vcvttps2uqqs 0x3f4a
#define MN_xrstors 0x3f57
#define MN_ss (MN_vfmsub231ss + 9)
#define MN_vfmsub231ss 0x3f5f
#define MN_vfnmsub231ss 0x3f6b
#define MN_vfmadd231ss 0x3f78
#define MN_vfnmadd231ss 0x3f84
#define MN_vfmsub132ss 0x3f91
#define MN_vfnmsub132ss 0x3f9d
#define MN_vfmadd132ss 0x3faa
#define MN_vfnmadd132ss 0x3fb6
#define MN_cvtsd2ss (MN_vcvtsd2ss + 1)
#define MN_vcvtsd2ss 0x3fc3
#define MN_vcvtsh2ss 0x3fcd
#define MN_cvtsi2ss (MN_vcvtsi2ss + 1)
#define MN_vcvtsi2ss 0x3fd7
#define MN_vcvtusi2ss 0x3fe1
#define MN_vfmsub213ss 0x3fec
#define MN_vfnmsub213ss 0x3ff8
#define MN_vfmadd213ss 0x4005
#define MN_vfnmadd213ss 0x4011
#define MN_vrcp14ss 0x401e
#define MN_vrsqrt14ss 0x4027
#define MN_vrcp28ss 0x4032
#define MN_vrsqrt28ss 0x403b
#define MN_subss (MN_vfmsubss + 3)
#define MN_vfmsubss 0x4046
#define MN_vfnmsubss 0x404f
#define MN_vsubss 0x4059
#define MN_addss (MN_v4fmaddss + 4)
#define MN_v4fmaddss 0x4060
#define MN_vfmaddss 0x406a
#define MN_v4fnmaddss 0x4073
#define MN_vfnmaddss 0x407e
#define MN_vaddss 0x4088
#define MN_roundss (MN_vroundss + 1)
#define MN_vroundss 0x408f
#define MN_cmpunordss (MN_vcmpunordss + 1)
#define MN_vcmpunordss 0x4098
#define MN_cmpordss (MN_vcmpordss + 1)
#define MN_vcmpordss 0x40a4
#define MN_vreducess 0x40ae
#define MN_vrangess 0x40b8
#define MN_vcmpngess 0x40c1
#define MN_vcmpgess 0x40cb
#define MN_vrndscaless 0x40d4
#define MN_cmpnless (MN_vcmpnless + 1)
#define MN_vcmpnless 0x40e0
#define MN_cmpless (MN_vcmpless + 1)
#define MN_vcmpless 0x40ea
#define MN_vcmpfalsess 0x40f3
#define MN_vcmptruess 0x40ff
#define MN_vscalefss 0x410a
#define MN_comiss (MN_ucomiss + 1)
#define MN_ucomiss (MN_vucomiss + 1)
#define MN_vucomiss 0x4114
#define MN_vcomiss 0x411d
#define MN_lss (MN_mulss + 2)
#define MN_mulss (MN_vmulss + 1)
#define MN_vmulss 0x4125
#define MN_vfixupimmss 0x412c
#define MN_minss (MN_vminss + 1)
#define MN_vminss 0x4138
#define MN_rcpss (MN_vrcpss + 1)
#define MN_vrcpss 0x413f
#define MN_cmpss (MN_vcmpss + 1)
#define MN_vcmpss 0x4146
#define MN_vgetexpss 0x414d
#define MN_vcmpunord_qss 0x4157
#define MN_vcmpord_qss 0x4165
#define MN_cmpneqss (MN_vcmpneqss + 1)
#define MN_vcmpneqss 0x4171
#define MN_cmpeqss (MN_vcmpeqss + 1)
#define MN_vcmpeqss 0x417b
#define MN_vcmpge_oqss 0x4184
#define MN_vcmple_oqss 0x4190
#define MN_vcmpfalse_oqss 0x419c
#define MN_vcmpneq_oqss 0x41ab
#define MN_vcmpeq_oqss 0x41b8
#define MN_vcmpgt_oqss 0x41c4
#define MN_vcmplt_oqss 0x41d0
#define MN_vcmpnge_uqss 0x41dc
#define MN_vcmpnle_uqss 0x41e9
#define MN_vcmptrue_uqss 0x41f6
#define MN_vcmpneq_uqss 0x4204
#define MN_vcmpeq_uqss 0x4211
#define MN_vcmpngt_uqss 0x421d
#define MN_vcmpnlt_uqss 0x422a
#define MN_vcmpunord_sss 0x4237
#define MN_vcmpord_sss 0x4245
#define MN_vcmpge_osss 0x4251
#define MN_vcmple_osss 0x425d
#define MN_vcmpfalse_osss 0x4269
#define MN_vcmpneq_osss 0x4278
#define MN_vcmpeq_osss 0x4285
#define MN_vcmpgt_osss 0x4291
#define MN_vcmplt_osss 0x429d
#define MN_vfpclassss 0x42a9
#define MN_vcmpnge_usss 0x42b4
#define MN_vcmpnle_usss 0x42c1
#define MN_vcmptrue_usss 0x42ce
#define MN_vcmpneq_usss 0x42dc
#define MN_vcmpeq_usss 0x42e9
#define MN_vcmpngt_usss 0x42f5
#define MN_vcmpnlt_usss 0x4302
#define MN_vcmpngtss 0x430f
#define MN_vcmpgtss 0x4319
#define MN_cmpnltss (MN_vcmpnltss + 1)
#define MN_vcmpnltss 0x4322
#define MN_cmpltss (MN_vcmpltss + 1)
#define MN_vcmpltss 0x432c
#define MN_vgetmantss 0x4335
#define MN_movntss 0x4340
#define MN_sqrtss (MN_rsqrtss + 1)
#define MN_rsqrtss (MN_vrsqrtss + 1)
#define MN_vrsqrtss 0x4348
#define MN_vsqrtss 0x4351
#define MN_vbroadcastss 0x4359
#define MN_divss (MN_vdivss + 1)
#define MN_vdivss 0x4366
#define MN_movss (MN_vmovss + 1)
#define MN_vmovss 0x436d
#define MN_maxss (MN_vminmaxss + 4)
#define MN_vminmaxss 0x4374
#define MN_vmaxss 0x437e
#define MN_vucomxss 0x4385
#define MN_vcomxss 0x438e
#define MN_vfrczss 0x4396
#define MN_bts 0x439e
#define MN_erets 0x43a2
#define MN_sets 0x43a8
#define MN_clts 0x43ad
#define MN_ctests 0x43b2
#define MN_outs 0x43b9
#define MN_setzus 0x43be
#define MN_movs (MN_cmovs + 1)
#define MN_cmovs (MN_cfcmovs + 2)
#define MN_cfcmovs 0x43c5
#define MN_fldl2t 0x43cd
#define MN_xlat 0x43d4
#define MN_bt 0x43d9
#define MN_fxtract 0x43dc
#define MN_lgdt 0x43e4
#define MN_sgdt 0x43e9
#define MN_lidt 0x43ee
#define MN_sidt 0x43f3
#define MN_fldt 0x43f8
#define MN_lldt 0x43fd
#define MN_sldt 0x4402
#define MN_ret (MN_iret + 1)
#define MN_iret (MN_uiret + 1)
#define MN_uiret 0x4407
#define MN_lret 0x440d
#define MN_seamret 0x4412
#define MN_sysret 0x441a
#define MN_hreset 0x4421
#define MN_pfcmpgt 0x4428
#define MN_ht 0x4430
#define MN_wait (MN_fwait + 1)
#define MN_fwait 0x4433
#define MN_mwait (MN_umwait + 1)
#define MN_umwait 0x4439
#define MN_mcommit 0x4440
#define MN_finit 0x4448
#define MN_skinit 0x444e
#define MN_fninit 0x4455
#define MN_vmgexit 0x445c
#define MN_sysexit 0x4464
#define MN_hlt 0x446c
#define MN_popcnt 0x4470
#define MN_lzcnt 0x4477
#define MN_tzcnt 0x447d
#define MN_hnt 0x4483
#define MN_int (MN_frndint + 4)
#define MN_frndint 0x4487
#define MN_not 0x448f
#define MN_invept 0x4493
#define MN_ccmpt 0x449a
#define MN_xsaveopt 0x44a0
#define MN_clflushopt 0x44a9
#define MN_fstpt 0x44b4
#define MN_xabort 0x44ba
#define MN_fsqrt 0x44c1
#define MN_pfrsqrt 0x44c7
#define MN_aesdeclast (MN_vaesdeclast + 1)
#define MN_vaesdeclast 0x44cf
#define MN_aesenclast (MN_vaesenclast + 1)
#define MN_vaesenclast 0x44db
#define MN_test (MN_ptest + 1)
#define MN_ptest (MN_vptest + 1)
#define MN_vptest 0x44e7
#define MN_xtest 0x44ee
#define MN_fst 0x44f4
#define MN_fist 0x44f8
#define MN_rdmsrlist 0x44fd
#define MN_wrmsrlist 0x4507
#define MN_aeskeygenassist (MN_vaeskeygenassist + 1)
#define MN_vaeskeygenassist 0x4511
#define MN_vmptrst 0x4522
#define MN_ftst 0x452a
#define MN_rmpadjust 0x452f
#define MN_ctestt 0x4539
#define MN_out 0x4540
#define MN_pext 0x4544
#define MN_bndcu 0x4549
#define MN_enclu 0x454f
#define MN_fcmovnu 0x4555
#define MN_lddqu (MN_vlddqu + 1)
#define MN_vlddqu 0x455d
#define MN_movdqu (MN_maskmovdqu + 4)
#define MN_maskmovdqu (MN_vmaskmovdqu + 1)
#define MN_vmaskmovdqu 0x4564
#define MN_vmovdqu 0x4570
#define MN_rdpkru 0x4578
#define MN_wrpkru 0x457f
#define MN_rdpru 0x4586
#define MN_eretu 0x458c
#define MN_fcmovu 0x4592
#define MN_imulzu 0x4599
#define MN_xgetbv 0x45a0
#define MN_xsetbv 0x45a7
#define MN_div (MN_fdiv + 1)
#define MN_fdiv 0x45ae
#define MN_idiv (MN_fidiv + 1)
#define MN_fidiv 0x45b3
#define MN_enclv 0x45b9
#define MN_fldenv 0x45bf
#define MN_fstenv 0x45c6
#define MN_fnstenv 0x45cd
#define MN_mov (MN_vpcmov + 3)
#define MN_vpcmov 0x45d5
#define MN_bndmov 0x45dc
#define MN_smov 0x45e3
#define MN_rex_w 0x45e8
#define MN_vcvttph2w 0x45ee
#define MN_vcvtph2w 0x45f8
#define MN_vpermi2w 0x4601
#define MN_vpmovm2w 0x460a
#define MN_vpermt2w 0x4613
#define MN_vpshaw 0x461c
#define MN_psraw (MN_vpsraw + 1)
#define MN_vpsraw 0x4623
#define MN_vphsubbw 0x462a
#define MN_cbw 0x4633
#define MN_psadbw (MN_vdbpsadbw + 3)
#define MN_vdbpsadbw 0x4637
#define MN_mpsadbw (MN_vmpsadbw + 1)
#define MN_vmpsadbw 0x4641
#define MN_vpsadbw 0x464a
#define MN_vphaddbw 0x4652
#define MN_punpckhbw (MN_vpunpckhbw + 1)
#define MN_vpunpckhbw 0x465b
#define MN_kunpckbw 0x4666
#define MN_punpcklbw (MN_vpunpcklbw + 1)
#define MN_vpunpcklbw 0x466f
#define MN_vphaddubw 0x467a
#define MN_phsubw (MN_vphsubw + 1)
#define MN_vphsubw 0x4684
#define MN_psubw (MN_vpsubw + 1)
#define MN_vpsubw 0x468c
#define MN_pmovsxbw (MN_vpmovsxbw + 1)
#define MN_vpmovsxbw 0x4693
#define MN_pmovzxbw (MN_vpmovzxbw + 1)
#define MN_vpmovzxbw 0x469d
#define MN_fldcw 0x46a7
#define MN_fstcw 0x46ad
#define MN_fnstcw 0x46b3
#define MN_phaddw (MN_vphaddw + 1)
#define MN_vphaddw 0x46ba
#define MN_kaddw 0x46c2
#define MN_paddw (MN_vpaddw + 1)
#define MN_vpaddw 0x46c8
#define MN_vpshldw 0x46cf
#define MN_kandw 0x46d7
#define MN_vpexpandw 0x46dd
#define MN_pblendw (MN_vpblendw + 1)
#define MN_vpblendw 0x46e7
#define MN_vpshrdw 0x46f0
#define MN_packssdw (MN_vpackssdw + 1)
#define MN_vpackssdw 0x46f8
#define MN_packusdw (MN_vpackusdw + 1)
#define MN_vpackusdw 0x4702
#define MN_vpmovusdw 0x470c
#define MN_vpmovsdw 0x4716
#define MN_vpmovdw 0x471f
#define MN_vpcomgew 0x4727
#define MN_vpcomlew 0x4730
#define MN_vpcmpnlew 0x4739
#define MN_vpcmplew 0x4743
#define MN_vpcomfalsew 0x474c
#define MN_vpcomtruew 0x4758
#define MN_pi2fw 0x4763
#define MN_pshufw 0x4769
#define MN_pavgw (MN_vpavgw + 1)
#define MN_vpavgw 0x4770
#define MN_prefetchw 0x4777
#define MN_pshufhw (MN_vpshufhw + 1)
#define MN_vpshufhw 0x4781
#define MN_pmulhw (MN_vpmulhw + 1)
#define MN_vpmulhw 0x478a
#define MN_pf2iw 0x4792
#define MN_pshuflw (MN_vpshuflw + 1)
#define MN_vpshuflw 0x4798
#define MN_vpshlw 0x47a1
#define MN_psllw (MN_vpsllw + 1)
#define MN_vpsllw 0x47a8
#define MN_pmullw (MN_vpmullw + 1)
#define MN_vpmullw 0x47af
#define MN_psrlw (MN_vpsrlw + 1)
#define MN_vpsrlw 0x47b7
#define MN_kshiftlw 0x47be
#define MN_vpblendmw 0x47c7
#define MN_vptestnmw 0x47d1
#define MN_vpcomw 0x47db
#define MN_vpermw 0x47e2
#define MN_vptestmw 0x47e9
#define MN_kandnw 0x47f2
#define MN_psignw (MN_vpsignw + 1)
#define MN_vpsignw 0x47f9
#define MN_vpcmpw 0x4801
#define MN_vpcomeqw 0x4808
#define MN_vpcomneqw 0x4811
#define MN_vpcmpneqw 0x481b
#define MN_pcmpeqw (MN_vpcmpeqw + 1)
#define MN_vpcmpeqw 0x4825
#define MN_vpmovusqw 0x482e
#define MN_vpmovsqw 0x4838
#define MN_vpmovqw 0x4841
#define MN_verw 0x4849
#define MN_pmulhrw 0x484e
#define MN_korw 0x4856
#define MN_kxnorw 0x485b
#define MN_kxorw 0x4862
#define MN_pinsrw (MN_vpinsrw + 1)
#define MN_vpinsrw 0x4868
#define MN_kshiftrw 0x4870
#define MN_pextrw (MN_vpextrw + 1)
#define MN_vpextrw 0x4879
#define MN_pabsw (MN_vpabsw + 1)
#define MN_vpabsw 0x4881
#define MN_pmaddubsw (MN_vpmaddubsw + 1)
#define MN_vpmaddubsw 0x4888
#define MN_phsubsw (MN_vphsubsw + 1)
#define MN_vphsubsw 0x4893
#define MN_psubsw (MN_vpsubsw + 1)
#define MN_vpsubsw 0x489c
#define MN_phaddsw (MN_vphaddsw + 1)
#define MN_vphaddsw 0x48a4
#define MN_paddsw (MN_vpaddsw + 1)
#define MN_vpaddsw 0x48ad
#define MN_lmsw 0x48b5
#define MN_smsw 0x48ba
#define MN_pminsw (MN_vpminsw + 1)
#define MN_vpminsw 0x48bf
#define MN_pmulhrsw (MN_vpmulhrsw + 1)
#define MN_vpmulhrsw 0x48c7
#define MN_vpcompressw 0x48d1
#define MN_fstsw 0x48dd
#define MN_fnstsw 0x48e3
#define MN_psubusw (MN_vpsubusw + 1)
#define MN_vpsubusw 0x48ea
#define MN_paddusw (MN_vpaddusw + 1)
#define MN_vpaddusw 0x48f3
#define MN_movsw 0x48fc
#define MN_pmaxsw (MN_vpmaxsw + 1)
#define MN_vpmaxsw 0x4902
#define MN_cbtw 0x490a
#define MN_vpcomgtw 0x490f
#define MN_pcmpgtw (MN_vpcmpgtw + 1)
#define MN_vpcmpgtw 0x4918
#define MN_vpcomltw 0x4921
#define MN_vpcmpnltw 0x492a
#define MN_vpcmpltw 0x4934
#define MN_vpopcntw 0x493d
#define MN_knotw 0x4946
#define MN_vprotw 0x494c
#define MN_vpbroadcastw 0x4953
#define MN_ktestw 0x4960
#define MN_kortestw 0x4967
#define MN_vcvttph2uw 0x4970
#define MN_vcvtph2uw 0x497b
#define MN_vpcomgeuw 0x4985
#define MN_vpcomleuw 0x498f
#define MN_vpcmpnleuw 0x4999
#define MN_vpcmpleuw 0x49a4
#define MN_vpcomfalseuw 0x49ae
#define MN_vpcomtrueuw 0x49bb
#define MN_pmulhuw (MN_vpmulhuw + 1)
#define MN_vpmulhuw 0x49c7
#define MN_vpcomuw 0x49d0
#define MN_pminuw (MN_vpminuw + 1)
#define MN_vpminuw 0x49d8
#define MN_vpcmpuw 0x49e0
#define MN_vpcomequw 0x49e8
#define MN_vpcomnequw 0x49f2
#define MN_vpcmpnequw 0x49fd
#define MN_vpcmpequw 0x4a08
#define MN_phminposuw (MN_vphminposuw + 1)
#define MN_vphminposuw 0x4a12
#define MN_vpcomgtuw 0x4a1e
#define MN_vpcomltuw 0x4a28
#define MN_vpcmpnltuw 0x4a32
#define MN_vpcmpltuw 0x4a3d
#define MN_pmaxuw (MN_vpmaxuw + 1)
#define MN_vpmaxuw 0x4a47
#define MN_vpsravw 0x4a4f
#define MN_vpshldvw 0x4a57
#define MN_vpshrdvw 0x4a60
#define MN_vpsllvw 0x4a69
#define MN_vpsrlvw 0x4a71
#define MN_kmovw 0x4a79
#define MN_vmovw 0x4a7f
#define MN_vpmacsww 0x4a85
#define MN_vpmacssww 0x4a8e
#define MN_movzw 0x4a98
#define MN_rex_x 0x4a9e
#define MN_fyl2x 0x4aa4
#define MN_rex64x 0x4aaa
#define MN_vcvtneps2bf16x 0x4ab1
#define MN_vfpclasspbf16x 0x4ac0
#define MN_vcvtneph2bf8x 0x4acf
#define MN_vcvtneph2hf8x 0x4add
#define MN_pfmax 0x4aeb
#define MN_adcx 0x4af1
#define MN_bndldx 0x4af6
#define MN_vfpclasspdx 0x4afd
#define MN_fclex 0x4b09
#define MN_fnclex 0x4b0f
#define MN_rex 0x4b16
#define MN_vcvtpd2phx 0x4b1a
#define MN_vcvtdq2phx 0x4b25
#define MN_vcvtudq2phx 0x4b30
#define MN_vcvtqq2phx 0x4b3c
#define MN_vcvtuqq2phx 0x4b47
#define MN_vcvt2ps2phx 0x4b53
#define MN_vcvtps2phx 0x4b5f
#define MN_vfpclassphx 0x4b6a
#define MN_shlx 0x4b76
#define MN_mulx 0x4b7b
#define MN_adox 0x4b80
#define MN_vcvttpd2dqx 0x4b85
#define MN_vcvtpd2dqx 0x4b91
#define MN_vcvttpd2udqx 0x4b9c
#define MN_vcvtpd2udqx 0x4ba9
#define MN_rex_rx 0x4bb5
#define MN_sarx 0x4bbc
#define MN_shrx 0x4bc1
#define MN_rorx 0x4bc6
#define MN_monitorx 0x4bcb
#define MN_rex_wrx 0x4bd4
#define MN_vcvtneph2bf8sx 0x4bdc
#define MN_vcvtneph2hf8sx 0x4beb
#define MN_vcvtpd2psx 0x4bfa
#define MN_vcvtph2psx 0x4c05
#define MN_vcvtqq2psx 0x4c10
#define MN_vcvtuqq2psx 0x4c1b
#define MN_vfpclasspsx 0x4c27
#define MN_vcvttpd2dqsx 0x4c33
#define MN_vcvttpd2udqsx 0x4c40
#define MN_movsx 0x4c4e
#define MN_mwaitx 0x4c54
#define MN_bndstx 0x4c5b
#define MN_rex_wx 0x4c62
#define MN_rexx 0x4c69
#define MN_vcvtps2phxx 0x4c6e
#define MN_movzx 0x4c7a
#define MN_rex64y 0x4c80
#define MN_vcvtneps2bf16y 0x4c87
#define MN_vfpclasspbf16y 0x4c96
#define MN_vcvtneph2bf8y 0x4ca5
#define MN_vcvtneph2hf8y 0x4cb3
#define MN_vfpclasspdy 0x4cc1
#define MN_loadiwkey 0x4ccd
#define MN_vcvtpd2phy 0x4cd7
#define MN_vcvtdq2phy 0x4ce2
#define MN_vcvtudq2phy 0x4ced
#define MN_vcvtqq2phy 0x4cf9
#define MN_vcvtuqq2phy 0x4d04
#define MN_vfpclassphy 0x4d10
#define MN_vcvttpd2dqy 0x4d1c
#define MN_vcvtpd2dqy 0x4d28
#define MN_vcvttpd2udqy 0x4d33
#define MN_vcvtpd2udqy 0x4d40
#define MN_rmpquery 0x4d4c
#define MN_vcvtneph2bf8sy 0x4d55
#define MN_vcvtneph2hf8sy 0x4d64
#define MN_clrssbsy 0x4d73
#define MN_setssbsy 0x4d7c
#define MN_vcvtpd2psy 0x4d85
#define MN_vcvtqq2psy 0x4d90
#define MN_vcvtuqq2psy 0x4d9b
#define MN_vfpclasspsy 0x4da7
#define MN_vcvttpd2dqsy 0x4db3
#define MN_vcvttpd2udqsy 0x4dc0
#define MN_rex64xy 0x4dce
#define MN_rexy 0x4dd6
#define MN_vcvtps2phxy 0x4ddb
#define MN_rexxy 0x4de7
#define MN_rex64z 0x4ded
#define MN_vfpclasspbf16z 0x4df4
#define MN_fldz 0x4e03
#define MN_vfpclasspdz 0x4e08
#define MN_vcvtpd2phz 0x4e14
#define MN_vcvtqq2phz 0x4e1f
#define MN_vcvtuqq2phz 0x4e2a
#define MN_vfpclassphz 0x4e36
#define MN_jz 0x4e42
#define MN_jnz 0x4e45
#define MN_repnz 0x4e49
#define MN_ccmpnz 0x4e4f
#define MN_loopnz 0x4e56
#define MN_setnz 0x4e5d
#define MN_ctestnz 0x4e63
#define MN_setzunz 0x4e6b
#define MN_cmovnz (MN_cfcmovnz + 2)
#define MN_cfcmovnz 0x4e73
#define MN_repz 0x4e7c
#define MN_ccmpz 0x4e81
#define MN_loopz 0x4e87
#define MN_vfpclasspsz 0x4e8d
#define MN_setz 0x4e99
#define MN_ctestz 0x4e9e
#define MN_setzuz 0x4ea5
#define MN_cmovz (MN_cfcmovz + 2)
#define MN_cfcmovz 0x4eac
#define MN_rex64xz 0x4eb4
#define MN_jecxz 0x4ebc
#define MN_jcxz 0x4ec2
#define MN_jrcxz 0x4ec7
#define MN_rexz 0x4ecd
#define MN_rexxz 0x4ed2
#define MN_rex64yz 0x4ed8
#define MN_rex64xyz 0x4ee0
#define MN_rexyz 0x4ee9
#define MN_rexxyz 0x4eef
#define MN__disp32_ 0x4ef6
#define MN__rex2_ 0x4eff
#define MN__vex2_ 0x4f06
#define MN__vex3_ 0x4f0d
#define MN__disp16_ 0x4f14
#define MN__disp8_ 0x4f1d
#define MN__load_ 0x4f25
#define MN__store_ 0x4f2c
#define MN__nooptimize_ 0x4f34
#define MN__nf_ 0x4f41
#define MN__rex_ 0x4f46
#define MN__evex_ 0x4f4c
#define MN__vex_ 0x4f53
#define MN__insn 0x4f59
